# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/pkg/apis/training/v1alpha1/generated.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_catalog_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2
from k8s.io.api.core.v1 import generated_pb2 as k8s_dot_io_dot_api_dot_core_dot_v1_dot_generated__pb2
from k8s.io.apimachinery.pkg.apis.meta.v1 import generated_pb2 as k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2
from k8s.io.apimachinery.pkg.runtime import generated_pb2 as k8s_dot_io_dot_apimachinery_dot_pkg_dot_runtime_dot_generated__pb2
from k8s.io.apimachinery.pkg.runtime.schema import generated_pb2 as k8s_dot_io_dot_apimachinery_dot_pkg_dot_runtime_dot_schema_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHgithub.com/metaprov/modelaapi/pkg/apis/training/v1alpha1/generated.proto\x12\x38github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1\x1aGgithub.com/metaprov/modelaapi/pkg/apis/catalog/v1alpha1/generated.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\x1a\"k8s.io/api/core/v1/generated.proto\x1a\x34k8s.io/apimachinery/pkg/apis/meta/v1/generated.proto\x1a/k8s.io/apimachinery/pkg/runtime/generated.proto\x1a\x36k8s.io/apimachinery/pkg/runtime/schema/generated.proto\"-\n\x18\x41lgorithmSearchSpaceSpec\x12\x11\n\tallowlist\x18\x01 \x03(\t\"\'\n\x11\x41udioPipelineSpec\x12\x12\n\nfeaturizer\x18\x01 \x01(\t\"c\n\x0c\x42\x61\x63ktestSpec\x12\x0f\n\x07sliding\x18\x01 \x01(\x08\x12\x0e\n\x06splits\x18\x02 \x01(\x05\x12\x14\n\x0cmaxTrainSize\x18\x03 \x01(\x05\x12\x0f\n\x07Horizon\x18\x04 \x01(\x05\x12\x0b\n\x03gap\x18\x05 \x01(\x05\"?\n\x0c\x42\x61selineSpec\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x11\n\tbaselines\x18\x02 \x03(\t\x12\x0b\n\x03\x61ll\x18\x03 \x01(\x08\"\xeb\x01\n\x11\x43\x61pacityStageSpec\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x17\n\x0fservingSiteName\x18\x02 \x01(\t\x12R\n\x05tests\x18\x03 \x03(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelTest\x12X\n\tresources\x18\x04 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ResourceSpec\"+\n\x0f\x43hangePointSpec\x12\t\n\x01N\x18\x01 \x01(\x05\x12\r\n\x05range\x18\x02 \x01(\x01\"$\n\x14\x43hatbotEstimatorSpec\x12\x0c\n\x04\x62\x61se\x18\x01 \x01(\t\"\x93\x01\n\x0e\x43heckpointSpec\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x1a\n\x12\x63heckpointInterval\x18\x02 \x01(\x05\x12T\n\x08location\x18\x03 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\"\x92\x01\n\x16\x43lassicalEstimatorSpec\x12\x15\n\ralgorithmName\x18\x01 \x01(\t\x12\x61\n\nparameters\x18\x02 \x03(\x0b\x32M.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.HyperParameterValue\"\x84\x02\n\nCronReport\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12V\n\x04spec\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.CronReportSpec\x12Z\n\x06status\x18\x03 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.CronReportStatus\"\x9c\x01\n\x13\x43ronReportCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x03 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\"\xa7\x01\n\x0e\x43ronReportList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12S\n\x05items\x18\x02 \x03(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.CronReport\"\xe8\x02\n\x0e\x43ronReportSpec\x12\x13\n\x0bversionName\x18\x01 \x01(\t\x12\r\n\x05owner\x18\x02 \x01(\t\x12V\n\x08schedule\x18\x03 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.RunSchedule\x12\r\n\x05range\x18\x04 \x01(\t\x12Z\n\x08template\x18\x05 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ReportTemplate\x12\x0e\n\x06paused\x18\x06 \x01(\x08\x12_\n\x0cnotification\x18\x07 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.NotificationSpec\"\x97\x03\n\x10\x43ronReportStatus\x12W\n\x07lastRun\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.LastRunStatus\x12;\n\x07nextRun\x18\x02 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12?\n\x0blastUpdated\x18\x03 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x1a\n\x12observedGeneration\x18\x04 \x01(\x03\x12\x15\n\rfailureReason\x18\x05 \x01(\t\x12\x16\n\x0e\x66\x61ilureMessage\x18\x06 \x01(\t\x12\x61\n\nconditions\x18\x07 \x03(\x0b\x32M.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.CronReportCondition\"a\n\x10\x43ustomReportSpec\x12M\n\x05pages\x18\x08 \x03(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.PageSpec\"K\n\x15\x43ustomSeasonalitySpec\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06period\x18\x02 \x01(\x01\x12\x14\n\x0c\x66ourierOrder\x18\x03 \x01(\x05\"L\n\nDataHashes\x12\x11\n\ttrainHash\x18\x01 \x01(\t\x12\x13\n\x0btestingHash\x18\x02 \x01(\t\x12\x16\n\x0evalidationHash\x18\x03 \x01(\t\"\x84\x02\n\rDataSplitSpec\x12\x0e\n\x06method\x18\x01 \x01(\t\x12\r\n\x05train\x18\x02 \x01(\x05\x12\x12\n\nvalidation\x18\x03 \x01(\x05\x12\x0c\n\x04test\x18\x04 \x01(\x05\x12\x13\n\x0bsplitColumn\x18\x05 \x01(\t\x12W\n\x08segments\x18\x06 \x03(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.SegmentSpec\x12\x14\n\x0ctrainDataset\x18\x07 \x01(\t\x12\x13\n\x0btestDataset\x18\x08 \x01(\t\x12\x19\n\x11validationDataset\x18\t \x01(\t\"`\n\rDataStageSpec\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x0f\n\x07labName\x18\x02 \x01(\t\x12\x18\n\x10\x64\x61tapipelineName\x18\x03 \x01(\t\x12\x13\n\x0b\x64ockerImage\x18\x04 \x01(\t\"\xa5\x01\n\x12\x44\x65\x65pEstimatorLayer\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12^\n\nparameters\x18\x03 \x03(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NNLayerParameter\x12\x13\n\x0binputLayers\x18\x04 \x03(\t\"\xe6\x01\n\x11\x44\x65\x65pEstimatorSpec\x12\\\n\x06layers\x18\x01 \x03(\x0b\x32L.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.DeepEstimatorLayer\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x11\n\tbatchSize\x18\x03 \x01(\x05\x12\x0e\n\x06\x65pochs\x18\x04 \x01(\x05\x12\x17\n\x0fvalidationSplit\x18\x05 \x01(\x05\x12\r\n\x05isSeq\x18\x06 \x01(\x08\x12\x0c\n\x04gpus\x18\x07 \x01(\x05\x12\x0c\n\x04loss\x18\x08 \x01(\t\"\x85\x02\n\x13\x44\x65ploymentStageSpec\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x17\n\x0fservingSiteName\x18\x02 \x01(\t\x12\x16\n\x0emanualApproval\x18\x03 \x01(\x08\x12R\n\x05tests\x18\x04 \x03(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelTest\x12X\n\tresources\x18\x05 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ResourceSpec\"?\n\x12\x44riftDetectionSpec\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x18\n\x10outlierAlgorithm\x18\x02 \x01(\t\".\n\x13\x44riftDetectorStatus\x12\x17\n\x0foutlierModelURI\x18\x01 \x01(\t\"R\n\rEarlyStopSpec\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x0f\n\x07initial\x18\x02 \x01(\x05\x12\x1f\n\x17minModelsWithNoProgress\x18\x03 \x01(\x05\"\x0f\n\rEnsembleRules\"\xf3\x01\n\x0c\x45nsembleSpec\x12\x0e\n\x06models\x18\x01 \x03(\t\x12\x64\n\nestimators\x18\x02 \x03(\x0b\x32P.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ClassicalEstimatorSpec\x12_\n\x05\x66inal\x18\x03 \x01(\x0b\x32P.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ClassicalEstimatorSpec\x12\x0c\n\x04type\x18\x04 \x01(\t\"_\n\rEnsemblesSpec\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x16\n\x0evotingEnsemble\x18\x02 \x01(\x08\x12\x18\n\x10stackingEnsemble\x18\x03 \x01(\x08\x12\x0b\n\x03top\x18\x04 \x01(\x05\"\xc7\x06\n\x1a\x46\x65\x61tureEngineeringPipeline\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08\x64\x61tatype\x18\x02 \x01(\t\x12\x0f\n\x07\x63olumns\x18\x03 \x03(\t\x12\x12\n\nimputation\x18\x04 \x01(\t\x12\x10\n\x08\x65ncoding\x18\x05 \x01(\t\x12\x0f\n\x07scaling\x18\x06 \x01(\t\x12\x16\n\x0e\x64iscretisation\x18\x07 \x01(\t\x12\x1e\n\x16variableTransformation\x18\x08 \x01(\t\x12\x17\n\x0foutlierHandling\x18\t \x01(\t\x12\x1e\n\x16\x64\x61tetimeTransformation\x18\n \x01(\t\x12X\n\x04text\x18\x0b \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.TextPipelineSpec\x12Z\n\x05image\x18\x0c \x01(\x0b\x32K.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ImagePipelineSpec\x12Z\n\x05\x61udio\x18\r \x01(\x0b\x32K.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.AudioPipelineSpec\x12Z\n\x05video\x18\x0e \x01(\x0b\x32K.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.VideoPipelineSpec\x12`\n\tgenerated\x18\x0f \x03(\x0b\x32M.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.GeneratedColumnSpec\x12]\n\x06\x63ustom\x18\x10 \x03(\x0b\x32M.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.GeneratedColumnSpec\x12\x0c\n\x04\x64rop\x18\x11 \x01(\x08\x12\x13\n\x0bpassthrough\x18\x12 \x01(\x08\"\x9a\x03\n\x1c\x46\x65\x61tureEngineeringSearchSpec\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x19\n\x11imbalancedHandler\x18\x02 \x01(\t\x12\x11\n\testimator\x18\x03 \x01(\t\x12\x11\n\tmaxModels\x18\x04 \x01(\x05\x12\x0f\n\x07maxTime\x18\x05 \x01(\x05\x12\x13\n\x0bmaxTrainers\x18\x06 \x01(\x05\x12\x11\n\tsamplePct\x18\x07 \x01(\x05\x12\x12\n\nautoRemove\x18\x08 \x01(\x08\x12\r\n\x05reuse\x18\t \x01(\x08\x12p\n\x18\x66\x65\x61tureSelectionTemplate\x18\n \x01(\x0b\x32N.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.FeatureSelectionSpec\x12Z\n\tearlyStop\x18\x0c \x01(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.EarlyStopSpec\"\x80\x01\n\x1e\x46\x65\x61tureEngineeringSearchStatus\x12^\n\x04\x62\x65st\x18\x01 \x01(\x0b\x32P.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.FeatureEngineeringSpec\"\xf7\x01\n\x16\x46\x65\x61tureEngineeringSpec\x12g\n\tpipelines\x18\x01 \x03(\x0b\x32T.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.FeatureEngineeringPipeline\x12\x11\n\timbalance\x18\x02 \x01(\t\x12\x61\n\tselection\x18\x03 \x01(\x0b\x32N.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.FeatureSelectionSpec\"8\n\x11\x46\x65\x61tureImportance\x12\x0f\n\x07\x66\x65\x61ture\x18\x01 \x01(\t\x12\x12\n\nimportance\x18\x02 \x01(\x01\":\n\x0b\x46\x65\x61tureInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\x01\"#\n\x0b\x46\x65\x61turePair\x12\t\n\x01x\x18\x01 \x01(\t\x12\t\n\x01y\x18\x02 \x01(\t\"\xdd\x01\n\x14\x46\x65\x61tureSelectionSpec\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x11\n\tembedding\x18\x03 \x01(\x08\x12\x0e\n\x06\x66ilter\x18\x04 \x01(\x08\x12\x0f\n\x07wrapper\x18\x05 \x01(\x08\x12\x10\n\x08pipeline\x18\x06 \x03(\t\x12\x1c\n\x14varianceThresholdPct\x18\x07 \x01(\x05\x12\x15\n\rcorrThreshold\x18\x08 \x01(\x05\x12\x13\n\x0bmaxFeatures\x18\t \x01(\x05\x12\x12\n\npercentile\x18\n \x01(\x05\x12\x10\n\x08reserved\x18\x0c \x03(\t\".\n\x0b\x46orecastObj\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x12\n\nlevelIndex\x18\x02 \x01(\x05\"F\n\x1a\x46orecastPostProcessingSpec\x12\x16\n\x0e\x63onnectionName\x18\x01 \x01(\t\x12\x10\n\x08\x66orecast\x18\x02 \x01(\x08\"\xd2\x03\n\x0c\x46orecastSpec\x12Z\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32L.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.TimeSeriesDataSpec\x12\x1a\n\x12\x63onfidenceInterval\x18\x02 \x01(\x05\x12X\n\x08\x62\x61\x63ktest\x18\x03 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.BacktestSpec\x12l\n\x0epostProcessing\x18\x04 \x01(\x0b\x32T.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ForecastPostProcessingSpec\x12\x0c\n\x04plot\x18\x05 \x01(\x08\x12\x18\n\x10plotChangePoints\x18\x06 \x01(\x08\x12Z\n\x0eoutputLocation\x18\x07 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\"s\n\x15GarbageCollectionSpec\x12\x19\n\x11\x63ollectAtStudyEnd\x18\x01 \x01(\x08\x12%\n\x1dkeepOnlyBestModelPerAlgorithm\x18\x02 \x01(\x08\x12\x18\n\x10keepPrunedModels\x18\x03 \x01(\x08\"\x83\x01\n\x17GarbageCollectionStatus\x12\x11\n\tcollected\x18\x01 \x01(\x05\x12U\n\x06models\x18\x02 \x03(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelResult\"f\n\x13GeneratedColumnSpec\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08\x64\x61tatype\x18\x02 \x01(\t\x12\r\n\x05\x66irst\x18\x03 \x01(\t\x12\x0e\n\x06second\x18\x04 \x01(\t\x12\x10\n\x08original\x18\x05 \x01(\t\"\xc6\x01\n\tHierarchy\x12\x0f\n\x07\x63olumns\x18\x01 \x03(\t\x12T\n\x0bgroupLevels\x18\x02 \x03(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Level\x12R\n\titemLevel\x18\x03 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Level\"h\n\rHierarchySpec\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x13\n\x0bgroupColumn\x18\x02 \x01(\t\x12\x16\n\x0esubGroupColumn\x18\x03 \x01(\t\x12\x19\n\x11subSubGroupColumn\x18\x04 \x01(\t\"[\n\x0bHolidaySpec\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x15\n\rholidayColumn\x18\x02 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x61tasetName\x18\x04 \x01(\t\"2\n\x13HyperParameterValue\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"o\n\x10HyperbandOptions\x12\x14\n\x0cminResources\x18\x01 \x01(\x05\x12\x14\n\x0cmaxResources\x18\x02 \x01(\x05\x12\x17\n\x0freductionFactor\x18\x03 \x01(\x05\x12\x16\n\x0e\x62ootstrapCount\x18\x04 \x01(\x05\"\'\n\x11ImagePipelineSpec\x12\x12\n\nfeaturizer\x18\x01 \x01(\t\";\n\x15ImbalanceHandlingSpec\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x11\n\timbalance\x18\x02 \x01(\t\"\x9a\x02\n\x14InterpretabilitySpec\x12\x0b\n\x03ice\x18\x01 \x01(\x08\x12W\n\x08icepairs\x18\x02 \x03(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.FeaturePair\x12\x0c\n\x04lime\x18\x03 \x01(\x08\x12\x0c\n\x04shap\x18\x04 \x01(\t\x12X\n\tshappairs\x18\x05 \x03(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.FeaturePair\x12\x16\n\x0e\x63ounterfactual\x18\x06 \x01(\x08\x12\x0e\n\x06\x61nchor\x18\x07 \x01(\x08\"\xd2\x02\n\x16InterpretabilityStatus\x12\x45\n\x11trainingStartTime\x18\x01 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x43\n\x0ftrainingEndTime\x18\x02 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x14\n\x0c\x65xplainerURI\x18\x03 \x01(\t\x12\x1a\n\x12trainShapValuesURI\x18\x04 \x01(\t\x12\x19\n\x11testShapValuesURI\x18\x05 \x01(\t\x12_\n\nimportance\x18\x06 \x03(\x0b\x32K.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.FeatureImportance\"Y\n\x05Level\x12\x0e\n\x06string\x18\x01 \x01(\t\x12\x0f\n\x07horizon\x18\x02 \x01(\x05\x12\x0c\n\x04\x66req\x18\x03 \x01(\t\x12\x11\n\taggregate\x18\x04 \x01(\t\x12\x0e\n\x06values\x18\x05 \x03(\t\"k\n\x13MedianPrunerOptions\x12\x15\n\rstartupTrials\x18\x01 \x01(\x05\x12\x13\n\x0bwarmupSteps\x18\x02 \x01(\x05\x12\x15\n\rintervalSteps\x18\x03 \x01(\x05\x12\x11\n\tminTrials\x18\x04 \x01(\x05\"\xf5\x01\n\x05Model\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12Q\n\x04spec\x18\x02 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelSpec\x12U\n\x06status\x18\x03 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelStatus\"\x96\x02\n\x10ModelAutobuilder\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\\\n\x04spec\x18\x02 \x01(\x0b\x32N.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelAutobuilderSpec\x12`\n\x06status\x18\x03 \x01(\x0b\x32P.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelAutobuilderStatus\"\xa2\x01\n\x19ModelAutobuilderCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x04 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x05 \x01(\t\x12\x0f\n\x07message\x18\x06 \x01(\t\"\xb3\x01\n\x14ModelAutobuilderList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12Y\n\x05items\x18\x02 \x03(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelAutobuilder\"\xbe\x06\n\x14ModelAutobuilderSpec\x12\x17\n\x0f\x64\x61taProductName\x18\x01 \x01(\t\x12\x1e\n\x16\x64\x61taProductVersionName\x18\x02 \x01(\t\x12\x16\n\x0e\x64\x61tasourceName\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x61tasetName\x18\x04 \x01(\t\x12T\n\x08location\x18\x05 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\x12\x0c\n\x04task\x18\x06 \x01(\t\x12\x0f\n\x07subtask\x18\x07 \x01(\t\x12\x11\n\tobjective\x18\x08 \x01(\t\x12\x14\n\x0ctargetColumn\x18\t \x01(\t\x12\x0f\n\x07maxTime\x18\n \x01(\x05\x12\x11\n\tmaxModels\x18\x0b \x01(\x05\x12\x14\n\x0c\x61\x63\x63\x65ssMethod\x18\x0c \x01(\t\x12\x11\n\tautoScale\x18\r \x01(\x08\x12\x1a\n\x12\x66\x65\x61tureEngineering\x18\x0e \x01(\x08\x12\x18\n\x10\x66\x65\x61tureSelection\x18\x0f \x01(\x08\x12\x0f\n\x07\x64\x61taapp\x18\x10 \x01(\x08\x12\\\n\x0e\x64\x61taSourceSpec\x18\x11 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSourceSpec\x12\x10\n\x08trainers\x18\x12 \x01(\x05\x12\x0f\n\x07sampler\x18\x13 \x01(\t\x12\x0f\n\x07\x61\x62orted\x18\x14 \x01(\x08\x12\r\n\x05owner\x18\x15 \x01(\t\x12X\n\tresources\x18\x16 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ResourceSpec\x12\x33\n\x06labRef\x18\x17 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12;\n\x0eservingSiteRef\x18\x18 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12\x13\n\x0b\x64\x61tasetType\x18\x19 \x01(\t\x12\x0c\n\x04\x66\x61st\x18\x1a \x01(\x08\"\x9a\x06\n\x16ModelAutobuilderStatus\x12\x14\n\x0c\x66latFileName\x18\x01 \x01(\t\x12\x16\n\x0e\x64\x61taSourceName\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x61tasetName\x18\x03 \x01(\t\x12\x11\n\tstudyName\x18\x04 \x01(\t\x12\x15\n\rbestModelName\x18\x06 \x01(\t\x12\x15\n\rpredictorName\x18\x07 \x01(\t\x12\x13\n\x0b\x64\x61taappName\x18\x08 \x01(\t\x12\x15\n\rimageRepoName\x18\t \x01(\t\x12\r\n\x05phase\x18\n \x01(\t\x12\x0c\n\x04rows\x18\x0b \x01(\x05\x12\x0c\n\x04\x63ols\x18\x0c \x01(\x05\x12\x10\n\x08\x66ileSize\x18\r \x01(\x05\x12\x0e\n\x06models\x18\x0e \x01(\x05\x12\x15\n\rtrainedModels\x18\x0f \x01(\x05\x12\x16\n\x0e\x62\x65stModelScore\x18\x10 \x01(\x01\x12\x63\n\testimator\x18\x11 \x01(\x0b\x32P.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ClassicalEstimatorSpec\x12=\n\tstartTime\x18\x12 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12;\n\x07\x65ndTime\x18\x13 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x1a\n\x12observedGeneration\x18\x15 \x01(\x03\x12\x15\n\rfailureReason\x18\x16 \x01(\t\x12\x16\n\x0e\x66\x61ilureMessage\x18\x17 \x01(\t\x12?\n\x0blastUpdated\x18\x18 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12g\n\nconditions\x18\x19 \x03(\x0b\x32S.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelAutobuilderCondition\"\x96\x02\n\x10ModelCompilerRun\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\\\n\x04spec\x18\x02 \x01(\x0b\x32N.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelCompilerRunSpec\x12`\n\x06status\x18\x03 \x01(\x0b\x32P.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelCompilerRunStatus\"\xa2\x01\n\x19ModelCompilerRunCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x04 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x05 \x01(\t\x12\x0f\n\x07message\x18\x06 \x01(\t\"\xb3\x01\n\x14ModelCompilerRunList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12Y\n\x05items\x18\x02 \x03(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelCompilerRun\"\x96\x01\n\x14ModelCompilerRunSpec\x12\x13\n\x0bversionName\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x11\n\tmodelName\x18\x03 \x01(\t\x12\r\n\x05owner\x18\x04 \x01(\t\x12\x10\n\x08priority\x18\x05 \x01(\t\x12\x10\n\x08\x63ompiler\x18\x06 \x01(\t\x12\x0e\n\x06target\x18\x07 \x01(\t\"\xc6\x03\n\x16ModelCompilerRunStatus\x12=\n\tstartTime\x18\x01 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x42\n\x0e\x63ompletionTime\x18\x02 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\r\n\x05phase\x18\x03 \x01(\t\x12\x1a\n\x12observedGeneration\x18\x04 \x01(\x03\x12\x13\n\x0b\x65valMetrics\x18\x05 \x01(\t\x12\x15\n\rfailureReason\x18\x06 \x01(\t\x12\x16\n\x0e\x66\x61ilureMessage\x18\x07 \x01(\t\x12\x10\n\x08progress\x18\x08 \x01(\x05\x12?\n\x0blastUpdated\x18\t \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12g\n\nconditions\x18\n \x03(\x0b\x32S.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelCompilerRunCondition\"\x97\x01\n\x0eModelCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x04 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x05 \x01(\t\x12\x0f\n\x07message\x18\x06 \x01(\t\"R\n\x0eModelImageSpec\x12\r\n\x05\x65xist\x18\x01 \x01(\x08\x12\x11\n\timageName\x18\x02 \x01(\t\x12\x1e\n\x16registryConnectionName\x18\x03 \x01(\t\"\x9d\x01\n\tModelList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12N\n\x05items\x18\x02 \x03(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\"\x8d\x02\n\rModelPipeline\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12Y\n\x04spec\x18\x02 \x01(\x0b\x32K.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineSpec\x12]\n\x06status\x18\x03 \x01(\x0b\x32M.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineStatus\"\x9f\x01\n\x16ModelPipelineCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x03 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\"\xad\x01\n\x11ModelPipelineList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12V\n\x05items\x18\x02 \x03(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipeline\"\x96\x02\n\x10ModelPipelineRun\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\\\n\x04spec\x18\x02 \x01(\x0b\x32N.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineRunSpec\x12`\n\x06status\x18\x03 \x01(\x0b\x32P.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineRunStatus\"\xa2\x01\n\x19ModelPipelineRunCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x04 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x05 \x01(\t\x12\x0f\n\x07message\x18\x06 \x01(\t\"\xb3\x01\n\x14ModelPipelineRunList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12Y\n\x05items\x18\x02 \x03(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineRun\"\xba\x01\n\x14ModelPipelineRunSpec\x12\x13\n\x0bversionName\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x61tasetName\x18\x03 \x01(\t\x12\x14\n\x0cpipelineName\x18\x04 \x01(\t\x12\r\n\x05owner\x18\x05 \x01(\t\x12\x10\n\x08priority\x18\x06 \x01(\t\x12\x0e\n\x06paused\x18\x07 \x01(\x08\x12\x0f\n\x07\x61\x62orted\x18\x08 \x01(\x08\x12\x0b\n\x03ttl\x18\t \x01(\x05\"\xf9\x02\n\x1bModelPipelineRunStageStatus\x12\r\n\x05phase\x18\x01 \x01(\t\x12\x10\n\x08\x61pproved\x18\x02 \x01(\x08\x12\x12\n\napprovedBy\x18\x03 \x01(\t\x12>\n\napprovedAt\x18\x04 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12=\n\tstartTime\x18\x07 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12;\n\x07\x65ndTime\x18\x08 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12Z\n\x07results\x18\t \x03(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelTestResult\x12\r\n\x05\x65rror\x18\n \x01(\t\"\x90\x0b\n\x16ModelPipelineRunStatus\x12\r\n\x05stage\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x61tasetName\x18\x02 \x01(\t\x12\x11\n\tstudyName\x18\x03 \x01(\t\x12\x11\n\tmodelName\x18\x04 \x01(\t\x12i\n\ndataStatus\x18\x05 \x01(\x0b\x32U.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineRunStageStatus\x12m\n\x0etrainingStatus\x18\x06 \x01(\x0b\x32U.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineRunStageStatus\x12h\n\tuatStatus\x18\x07 \x01(\x0b\x32U.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineRunStageStatus\x12m\n\x0e\x63\x61pacityStatus\x18\x08 \x01(\x0b\x32U.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineRunStageStatus\x12o\n\x10\x64\x65ploymentStatus\x18\t \x01(\x0b\x32U.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineRunStageStatus\x12l\n\rreleaseStatus\x18\n \x01(\x0b\x32U.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineRunStageStatus\x12o\n\x10monitoringStatus\x18\x0b \x01(\x0b\x32U.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineRunStageStatus\x12m\n\x0elabelingStatus\x18\x0c \x01(\x0b\x32U.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineRunStageStatus\x12=\n\tstartTime\x18\r \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12;\n\x07\x65ndTime\x18\x0e \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\r\n\x05phase\x18\x0f \x01(\t\x12\x1a\n\x12observedGeneration\x18\x10 \x01(\x03\x12\x13\n\x0b\x65valMetrics\x18\x11 \x01(\t\x12\x15\n\rfailureReason\x18\x12 \x01(\t\x12\x16\n\x0e\x66\x61ilureMessage\x18\x13 \x01(\t\x12\x10\n\x08progress\x18\x14 \x01(\x05\x12\x13\n\x0btriggeredBy\x18\x15 \x01(\t\x12?\n\x0blastUpdated\x18\x16 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12g\n\nconditions\x18\x17 \x03(\x0b\x32S.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineRunCondition\"\xbc\x08\n\x11ModelPipelineSpec\x12\x13\n\x0bversionName\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12y\n\x0f\x64\x61tasetSelector\x18\x03 \x03(\x0b\x32`.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineSpec.DatasetSelectorEntry\x12U\n\x04\x64\x61ta\x18\x04 \x01(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.DataStageSpec\x12]\n\x08training\x18\x05 \x01(\x0b\x32K.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.TrainingStageSpec\x12S\n\x03uat\x18\x06 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.UATStageSpec\x12]\n\x08\x63\x61pacity\x18\x07 \x01(\x0b\x32K.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.CapacityStageSpec\x12\x61\n\ndeployment\x18\t \x01(\x0b\x32M.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.DeploymentStageSpec\x12[\n\x07release\x18\n \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ReleaseStageSpec\x12V\n\x08schedule\x18\x0c \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.RunSchedule\x12\r\n\x05owner\x18\r \x01(\t\x12\x1b\n\x13\x61pproverAccountName\x18\x0e \x01(\t\x12_\n\x0cnotification\x18\x0f \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.NotificationSpec\x12\x19\n\x11\x62\x61selineModelName\x18\x10 \x01(\t\x12\x10\n\x08priority\x18\x11 \x01(\t\x12\x0e\n\x06paused\x18\x12 \x01(\x08\x1a\x36\n\x14\x44\x61tasetSelectorEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9d\x03\n\x13ModelPipelineStatus\x12W\n\x07lastRun\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.LastRunStatus\x12;\n\x07nextRun\x18\x02 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x1a\n\x12observedGeneration\x18\x03 \x01(\x03\x12?\n\x0blastUpdated\x18\x04 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x15\n\rfailureReason\x18\x05 \x01(\t\x12\x16\n\x0e\x66\x61ilureMessage\x18\x06 \x01(\t\x12\x64\n\nconditions\x18\x07 \x03(\x0b\x32P.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineCondition\"W\n\x0bModelResult\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03\x61lg\x18\x02 \x01(\t\x12\r\n\x05score\x18\x03 \x01(\x01\x12\r\n\x05\x65rror\x18\x04 \x01(\x08\x12\x0f\n\x07trialID\x18\x05 \x01(\x05\"\x8a\x0e\n\tModelSpec\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x13\n\x0bversionName\x18\x02 \x01(\t\x12\x14\n\x0cmodelVersion\x18\x04 \x01(\t\x12\x11\n\tstudyName\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x61tasetName\x18\x06 \x01(\t\x12\x0c\n\x04task\x18\x07 \x01(\t\x12\x0f\n\x07subtask\x18\x08 \x01(\t\x12\x11\n\tobjective\x18\t \x01(\t\x12l\n\x12\x66\x65\x61tureEngineering\x18\n \x01(\x0b\x32P.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.FeatureEngineeringSpec\x12\x63\n\testimator\x18\x0b \x01(\x0b\x32P.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ClassicalEstimatorSpec\x12X\n\x03\x64nn\x18\x0c \x01(\x0b\x32K.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.DeepEstimatorSpec\x12_\n\x07\x63hatbot\x18\r \x01(\x0b\x32N.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ChatbotEstimatorSpec\x12`\n\x0cnlpEstimator\x18\x0e \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NLPEstimatorSpec\x12X\n\x08\x65nsemble\x18\x0f \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.EnsembleSpec\x12X\n\x08training\x18\x10 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.TrainingSpec\x12V\n\x07serving\x18\x11 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ServingSpec\x12\x0e\n\x06tested\x18\x12 \x01(\x08\x12\x0f\n\x07\x61\x62orted\x18\x13 \x01(\x08\x12\x10\n\x08packaged\x18\x14 \x01(\x08\x12\x11\n\tpublished\x18\x15 \x01(\x08\x12\x0e\n\x06pushed\x18\x16 \x01(\x08\x12\x10\n\x08reported\x18\x17 \x01(\x08\x12\x0e\n\x06paused\x18\x18 \x01(\x08\x12\x10\n\x08profiled\x18\x19 \x01(\x08\x12\x10\n\x08\x61rchived\x18\x1a \x01(\x08\x12\x12\n\nforecasted\x18\x1b \x01(\x08\x12\x10\n\x08released\x18\x1c \x01(\x08\x12\x11\n\texplained\x18\x1d \x01(\x08\x12\x15\n\rcodeGenerated\x18\x1e \x01(\x08\x12\x10\n\x08\x62\x61seline\x18\x1f \x01(\x08\x12\x18\n\x10genDriftDetector\x18  \x01(\x08\x12\x0c\n\x04\x66\x61st\x18! \x01(\x08\x12\x0f\n\x07\x66lagged\x18\" \x01(\x08\x12T\n\x08location\x18# \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\x12X\n\x08\x66orecast\x18$ \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ForecastSpec\x12Z\n\x0b\x63ompilation\x18% \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.CompilerSpec\x12\x1d\n\x15\x61\x63tiveDeadlineSeconds\x18& \x01(\x03\x12\x15\n\restimatorType\x18\' \x01(\t\x12\x0b\n\x03ttl\x18( \x01(\x05\x12\x12\n\nmodelClass\x18) \x01(\t\x12\x0f\n\x07trialID\x18* \x01(\x05\x12X\n\ngovernance\x18+ \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.GovernanceSpec\x12h\n\x10interpretability\x18, \x01(\x0b\x32N.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.InterpretabilitySpec\"\xa9\x1a\n\x0bModelStatus\x12=\n\tstartTime\x18\x01 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x45\n\x11trainingStartTime\x18\x02 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x43\n\x0ftrainingEndTime\x18\x03 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x44\n\x10testingStartTime\x18\x04 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x42\n\x0etestingEndTime\x18\x05 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12;\n\x07\x65ndTime\x18\x06 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0f\n\x07\x63vScore\x18\x07 \x01(\x01\x12\x15\n\rtrainingScore\x18\x08 \x01(\x01\x12\x11\n\ttestScore\x18\t \x01(\x01\x12\x0c\n\x04\x63ost\x18\n \x01(\x01\x12\x0c\n\x04\x62\x65st\x18\x0b \x01(\x08\x12P\n\x02\x63v\x18\x0c \x03(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Measurement\x12S\n\x05train\x18\r \x03(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Measurement\x12R\n\x04test\x18\x0e \x03(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Measurement\x12\r\n\x05phase\x18\x0f \x01(\t\x12\x12\n\nreportName\x18\x10 \x01(\t\x12\x11\n\treportUri\x18\x11 \x01(\t\x12\x13\n\x0bmanifestUri\x18\x12 \x01(\t\x12\x12\n\nweightsUri\x18\x13 \x01(\t\x12\x17\n\x0flabelEncoderUri\x18\x14 \x01(\t\x12\x0f\n\x07logsUri\x18\x15 \x01(\t\x12\x12\n\nprofileUri\x18\x16 \x01(\t\x12\x1c\n\x14misclassificationUri\x18\x17 \x01(\t\x12\x0e\n\x06tarUri\x18\x18 \x01(\t\x12\x0e\n\x06\x61ppUri\x18\x19 \x01(\t\x12\x11\n\timageName\x18\x1a \x01(\t\x12_\n\nimportance\x18\x1b \x03(\x0b\x32K.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.FeatureImportance\x12j\n\x15permutationImportance\x18\x1c \x03(\x0b\x32K.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.FeatureImportance\x12\x13\n\x0b\x66orecastUri\x18\x1d \x01(\t\x12X\n\x07runtime\x18\x1e \x01(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.RuntimeStatus\x12X\n\x0ctrainDataset\x18  \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\x12W\n\x0btestDataset\x18! \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\x12]\n\x11validationDataset\x18\" \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\x12\x1a\n\x12observedGeneration\x18# \x01(\x03\x12\x14\n\x0ctrainingRows\x18$ \x01(\x05\x12\x13\n\x0btestingRows\x18% \x01(\x05\x12\x16\n\x0evalidationRows\x18& \x01(\x05\x12\x15\n\rfailureReason\x18\' \x01(\t\x12\x16\n\x0e\x66\x61ilureMessage\x18( \x01(\t\x12\x10\n\x08progress\x18) \x01(\x05\x12\x13\n\x0bsizeInBytes\x18* \x01(\x05\x12\x0f\n\x07latency\x18+ \x01(\x01\x12\x0b\n\x03url\x18, \x01(\t\x12\x15\n\rpredictorName\x18- \x01(\t\x12>\n\nreleasedAt\x18. \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x13\n\x0btarFileHash\x18/ \x01(\t\x12\x11\n\timageHash\x18\x30 \x01(\t\x12^\n\x10trainingDataHash\x18\x31 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.DataHashes\x12h\n\x11trainingResources\x18\x32 \x01(\x0b\x32M.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ResourceConsumption\x12g\n\x10testingResources\x18\x33 \x01(\x0b\x32M.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ResourceConsumption\x12\x11\n\ttrainedBy\x18\x34 \x01(\t\x12\x0c\n\x04team\x18\x35 \x01(\t\x12\x10\n\x08\x65ndpoint\x18\x39 \x01(\t\x12K\n\x04logs\x18: \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Logs\x12V\n\x08rocCurve\x18; \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.RocAucCurve\x12Q\n\x07prCurve\x18< \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.PRCurve\x12\x66\n\x14trainConfusionMatrix\x18= \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ConfusionMatrix\x12\x65\n\x13testConfusionMatrix\x18> \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ConfusionMatrix\x12\x61\n\x16\x63orrelationsWithTarget\x18? \x03(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Correlation\x12Z\n\x0ftopCorrelations\x18@ \x03(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Correlation\x12?\n\x0blastUpdated\x18\x41 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12`\n\x10governanceStatus\x18\x42 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.GovernanceStatus\x12j\n\x10interpretability\x18\x43 \x01(\x0b\x32P.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.InterpretabilityStatus\x12O\n\x06images\x18\x44 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Images\x12\\\n\nconditions\x18\x45 \x03(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelCondition\"\x88\x01\n\tModelTest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tprevModel\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x61tasetName\x18\x03 \x01(\t\x12\x0e\n\x06\x63olumn\x18\x04 \x01(\t\x12\x0e\n\x06metric\x18\x05 \x01(\t\x12\x0b\n\x03min\x18\x06 \x01(\x01\x12\x0b\n\x03max\x18\x07 \x01(\x01\x12\x0b\n\x03\x61gg\x18\x08 \x01(\t\"\xea\x01\n\x0fModelTestResult\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x61tasetName\x18\x02 \x01(\t\x12\x11\n\tmodelName\x18\x03 \x01(\t\x12\x0e\n\x06\x63olumn\x18\x04 \x01(\t\x12\r\n\x05\x65rror\x18\x05 \x01(\t\x12\x0e\n\x06metric\x18\x06 \x01(\t\x12\x13\n\x0b\x61\x63tualValue\x18\x07 \x01(\x01\x12\x0e\n\x06passed\x18\x08 \x01(\x08\x12\x36\n\x02\x61t\x18\t \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x15\n\rdurationInSec\x18\n \x01(\x05\" \n\x10NLPEstimatorSpec\x12\x0c\n\x04\x62\x61se\x18\x01 \x01(\t\"/\n\x10NNLayerParameter\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xfe\x01\n\x08Notebook\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12T\n\x04spec\x18\x02 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NotebookSpec\x12X\n\x06status\x18\x03 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NotebookStatus\"\x9a\x01\n\x11NotebookCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x04 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x05 \x01(\t\x12\x0f\n\x07message\x18\x06 \x01(\t\"\xa3\x01\n\x0cNotebookList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12Q\n\x05items\x18\x02 \x03(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Notebook\"\x87\x02\n\x0bNotebookRun\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12W\n\x04spec\x18\x02 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NotebookRunSpec\x12[\n\x06status\x18\x03 \x01(\x0b\x32K.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NotebookRunStatus\"\x9d\x01\n\x14NotebookRunCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x04 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x05 \x01(\t\x12\x0f\n\x07message\x18\x06 \x01(\t\"\xa9\x01\n\x0fNotebookRunList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12T\n\x05items\x18\x02 \x03(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NotebookRun\"\xc3\x02\n\x0fNotebookRunSpec\x12\x13\n\x0bversionName\x18\x01 \x01(\t\x12\x14\n\x0cnotebookName\x18\x02 \x01(\t\x12Z\n\x06values\x18\x03 \x03(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NotebookVarValue\x12\r\n\x05owner\x18\x04 \x01(\t\x12X\n\tresources\x18\x05 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ResourceSpec\x12\x0b\n\x03ttl\x18\x06 \x01(\x05\x12\x33\n\x06labRef\x18\x07 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\"\xf0\x03\n\x11NotebookRunStatus\x12\r\n\x05phase\x18\x01 \x01(\t\x12=\n\tstartTime\x18\x02 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12;\n\x07\x65ndTime\x18\x03 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x1a\n\x12observedGeneration\x18\x04 \x01(\x03\x12\x15\n\rfailureReason\x18\x05 \x01(\t\x12\x16\n\x0e\x66\x61ilureMessage\x18\x06 \x01(\t\x12\x13\n\x0btriggeredBy\x18\x07 \x01(\t\x12K\n\x04logs\x18\x08 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Logs\x12?\n\x0blastUpdated\x18\t \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x62\n\nconditions\x18\n \x03(\x0b\x32N.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NotebookRunCondition\"\x94\x04\n\x0cNotebookSpec\x12\x13\n\x0bversionName\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x36\n\tschemaRef\x18\x03 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12\x11\n\timageName\x18\x04 \x01(\t\x12\x14\n\x0crequirements\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65\x62Packages\x18\x06 \x01(\t\x12\x0c\n\x04vars\x18\x07 \x03(\t\x12T\n\x08location\x18\x08 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\x12\r\n\x05owner\x18\t \x01(\t\x12X\n\tresources\x18\n \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ResourceSpec\x12\x1d\n\x15\x61\x63tiveDeadlineSeconds\x18\x0b \x01(\x03\x12V\n\x08schedule\x18\x0c \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.RunSchedule\x12\x10\n\x08priority\x18\r \x01(\t\x12\x0e\n\x06paused\x18\x0e \x01(\x08\"\xaf\x03\n\x0eNotebookStatus\x12\r\n\x05image\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x1a\n\x12observedGeneration\x18\x03 \x01(\x03\x12W\n\x07lastRun\x18\x04 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.LastRunStatus\x12;\n\x07nextRun\x18\x05 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12?\n\x0blastUpdated\x18\x06 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x15\n\rfailureReason\x18\x07 \x01(\t\x12\x16\n\x0e\x66\x61ilureMessage\x18\x08 \x01(\t\x12_\n\nconditions\x18\t \x03(\x0b\x32K.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NotebookCondition\"/\n\x10NotebookVarValue\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\x84\x01\n\x17PercentilePrunerOptions\x12\x12\n\npercentile\x18\x01 \x01(\x05\x12\x15\n\rstartupTrials\x18\x02 \x01(\x05\x12\x13\n\x0bwarmupSteps\x18\x03 \x01(\x05\x12\x16\n\x0eintervalTrials\x18\x04 \x01(\x05\x12\x11\n\tminTrials\x18\x05 \x01(\x05\"G\n\x15PeriodSeasonalitySpec\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x0f\n\x07periods\x18\x02 \x01(\x05\x12\x0c\n\x04mode\x18\x03 \x01(\t\"=\n\nPeriodSpec\x12\x10\n\x08interval\x18\x01 \x01(\t\x12\r\n\x05start\x18\x02 \x01(\x05\x12\x0e\n\x06length\x18\x03 \x01(\x05\"\x93\x04\n\nPrunerSpec\x12\x0c\n\x04type\x18\x01 \x01(\t\x12]\n\x06median\x18\x02 \x01(\x0b\x32M.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.MedianPrunerOptions\x12\x65\n\npercentile\x18\x03 \x01(\x0b\x32Q.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.PercentilePrunerOptions\x12m\n\x11successiveHalving\x18\x04 \x01(\x0b\x32R.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.SuccessiveHalvingOptions\x12]\n\thyperband\x18\x05 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.HyperbandOptions\x12\x63\n\tthreshold\x18\x06 \x01(\x0b\x32P.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ThresholdPrunerOptions\"F\n\rRegressorSpec\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\npriorScale\x18\x02 \x01(\x01\x12\x13\n\x0bstandardize\x18\x03 \x01(\x08\"\xa5\x02\n\x10ReleaseStageSpec\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x17\n\x0fservingSiteName\x18\x02 \x01(\t\x12\x15\n\rpredictorName\x18\x03 \x01(\t\x12^\n\x08template\x18\x04 \x01(\x0b\x32L.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ModelDeploymentSpec\x12\x16\n\x0emanualApproval\x18\x05 \x01(\x08\x12X\n\tresources\x18\x07 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ResourceSpec\"\xf8\x01\n\x06Report\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12R\n\x04spec\x18\x02 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ReportSpec\x12V\n\x06status\x18\x03 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ReportStatus\"\x98\x01\n\x0fReportCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x04 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x05 \x01(\t\x12\x0f\n\x07message\x18\x06 \x01(\t\"\x9f\x01\n\nReportList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12O\n\x05items\x18\x02 \x03(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Report\"\x9a\x04\n\nReportSpec\x12\x13\n\x0bversionName\x18\x01 \x01(\t\x12\x36\n\tentityRef\x18\x02 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12T\n\x08location\x18\x04 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\x12\x12\n\nreportType\x18\x05 \x01(\t\x12\x0e\n\x06\x66ormat\x18\x06 \x01(\t\x12\x14\n\x0cnotifierName\x18\x07 \x01(\t\x12\r\n\x05owner\x18\x08 \x01(\t\x12X\n\tresources\x18\t \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ResourceSpec\x12\x1d\n\x15\x61\x63tiveDeadlineSeconds\x18\n \x01(\x03\x12Z\n\x06\x63ustom\x18\x0b \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.CustomReportSpec\x12\x16\n\x0e\x63ronReportName\x18\x0c \x01(\t\x12\x33\n\x06labRef\x18\r \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\"\xde\x03\n\x0cReportStatus\x12=\n\tstartTime\x18\x02 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12;\n\x07\x65ndTime\x18\x03 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\r\n\x05phase\x18\x04 \x01(\t\x12\x0b\n\x03uri\x18\x05 \x01(\t\x12\x1a\n\x12observedGeneration\x18\x06 \x01(\x03\x12\x15\n\rfailureReason\x18\x07 \x01(\t\x12\x16\n\x0e\x66\x61ilureMessage\x18\x08 \x01(\t\x12K\n\x04logs\x18\t \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Logs\x12?\n\x0blastUpdated\x18\n \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12]\n\nconditions\x18\x0b \x03(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ReportCondition\"d\n\x0eReportTemplate\x12R\n\x04spec\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ReportSpec\"<\n\x13ResourceConsumption\x12\x0b\n\x03\x63pu\x18\x01 \x01(\x01\x12\x0b\n\x03mem\x18\x02 \x01(\x01\x12\x0b\n\x03gpu\x18\x03 \x01(\x01\"\xf1\x01\n\rRuntimeStatus\x12\x15\n\rpythonVersion\x18\x01 \x01(\t\x12\x11\n\tpythonCmd\x18\x02 \x01(\t\x12\n\n\x02os\x18\x03 \x01(\t\x12s\n\x0epythonPackages\x18\x04 \x03(\x0b\x32[.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.RuntimeStatus.PythonPackagesEntry\x1a\x35\n\x13PythonPackagesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf2\x03\n\nSearchSpec\x12\x0f\n\x07sampler\x18\x01 \x01(\t\x12T\n\x06pruner\x18\x02 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.PrunerSpec\x12\x0f\n\x07maxCost\x18\x03 \x01(\x05\x12\x0f\n\x07maxTime\x18\x04 \x01(\x05\x12\x11\n\tmaxModels\x18\x05 \x01(\x05\x12\x14\n\x0cminBestScore\x18\x06 \x01(\x01\x12\x10\n\x08trainers\x18\x07 \x01(\x05\x12\x0c\n\x04test\x18\x08 \x01(\x05\x12\x11\n\tretainTop\x18\t \x01(\x05\x12\x13\n\x0bretainedFor\x18\n \x01(\x05\x12g\n\x0bsearchSpace\x18\x0b \x01(\x0b\x32R.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.AlgorithmSearchSpaceSpec\x12Z\n\tearlyStop\x18\x0c \x01(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.EarlyStopSpec\x12\x11\n\tobjective\x18\x0e \x01(\t\x12\x12\n\nobjective2\x18\x0f \x01(\t\"<\n\x0bSegmentSpec\x12\x12\n\ncolumnName\x18\x01 \x01(\t\x12\n\n\x02op\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"w\n\x0bServingSpec\x12X\n\tresources\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ResourceSpec\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\t\"\xf5\x01\n\x05Study\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12Q\n\x04spec\x18\x02 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.StudySpec\x12U\n\x06status\x18\x03 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.StudyStatus\"\x97\x01\n\x0eStudyCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x04 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x05 \x01(\t\x12\x0f\n\x07message\x18\x06 \x01(\t\"\xc5\x01\n\x11StudyForecastSpec\x12X\n\x08template\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ForecastSpec\x12V\n\thierarchy\x18\x02 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Hierarchy\"\x9d\x01\n\tStudyList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12N\n\x05items\x18\x02 \x03(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\"\x84\x02\n\x10StudyPhaseStatus\x12=\n\tstartTime\x18\x01 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12;\n\x07\x65ndTime\x18\x02 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0f\n\x07waiting\x18\x03 \x01(\x05\x12\x0f\n\x07running\x18\x04 \x01(\x05\x12\x0e\n\x06\x66\x61iled\x18\x05 \x01(\x05\x12\x11\n\tcompleted\x18\x06 \x01(\x05\x12\x11\n\tbestScore\x18\x07 \x01(\x01\x12\x1c\n\x14modelsWithNoProgress\x18\x08 \x01(\x05\"a\n\x11StudyScheduleSpec\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12;\n\x07startAt\x18\x02 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\"\xbd\x0f\n\tStudySpec\x12\x13\n\x0bversionName\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x33\n\x06labRef\x18\x03 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12\x13\n\x0b\x64\x61tasetName\x18\x04 \x01(\t\x12\x0c\n\x04task\x18\x05 \x01(\t\x12\x0f\n\x07subtask\x18\x06 \x01(\t\x12h\n\x08\x66\x65Search\x18\x07 \x01(\x0b\x32V.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.FeatureEngineeringSearchSpec\x12i\n\x10imbalanceHandler\x18\x08 \x01(\x0b\x32O.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ImbalanceHandlingSpec\x12X\n\x08\x62\x61seline\x18\t \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.BaselineSpec\x12T\n\x06search\x18\n \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.SearchSpec\x12Z\n\tensembles\x18\x0b \x01(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.EnsemblesSpec\x12`\n\x10trainingTemplate\x18\x0c \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.TrainingSpec\x12^\n\x0fservingTemplate\x18\r \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ServingSpec\x12]\n\x08\x66orecast\x18\x0e \x01(\x0b\x32K.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.StudyForecastSpec\x12]\n\x08schedule\x18\x0f \x01(\x0b\x32K.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.StudyScheduleSpec\x12h\n\x10interpretability\x18\x10 \x01(\x0b\x32N.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.InterpretabilitySpec\x12\x64\n\x0e\x64riftDetection\x18\x11 \x01(\x0b\x32L.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.DriftDetectionSpec\x12\x0f\n\x07\x61\x62orted\x18\x12 \x01(\x08\x12\x10\n\x08reported\x18\x13 \x01(\x08\x12\x0e\n\x06paused\x18\x14 \x01(\x08\x12\x10\n\x08profiled\x18\x15 \x01(\x08\x12\x16\n\x0emodelPublished\x18\x16 \x01(\x08\x12\x18\n\x10modelImagePushed\x18\x17 \x01(\x08\x12\x16\n\x0emodelExplained\x18\x18 \x01(\x08\x12\x0c\n\x04\x66\x61st\x18\x19 \x01(\x08\x12T\n\x08location\x18\x1a \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\x12\r\n\x05owner\x18\x1b \x01(\t\x12Z\n\x0b\x63ompilation\x18\x1c \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.CompilerSpec\x12\x10\n\x08template\x18\x1d \x01(\x08\x12\x0f\n\x07\x66lagged\x18\x1e \x01(\x08\x12_\n\x0cnotification\x18\x1f \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.NotificationSpec\x12\\\n\nmodelImage\x18  \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelImageSpec\x12[\n\x02gc\x18! \x01(\x0b\x32O.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.GarbageCollectionSpec\x12\x0b\n\x03ttl\x18\" \x01(\x05\x12\x14\n\x0cmodelVersion\x18# \x01(\t\x12\x15\n\rtimeoutInSecs\x18$ \x01(\x05\x12\x15\n\rcodeGenerated\x18% \x01(\x08\"\x95\x0f\n\x0bStudyStatus\x12\x0e\n\x06models\x18\x01 \x01(\x05\x12=\n\tstartTime\x18\x02 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12;\n\x07\x65ndTime\x18\x03 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x11\n\tbestModel\x18\x04 \x01(\t\x12\x16\n\x0e\x62\x65stModelScore\x18\x05 \x01(\x01\x12\x12\n\nprofileUri\x18\x06 \x01(\t\x12\x11\n\treportUri\x18\x07 \x01(\t\x12\x12\n\nreportName\x18\x08 \x01(\t\x12\r\n\x05phase\x18\t \x01(\t\x12\x1a\n\x12observedGeneration\x18\n \x01(\x03\x12X\n\x0ctrainDataset\x18\x0b \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\x12W\n\x0btestDataset\x18\x0c \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\x12]\n\x11validationDataset\x18\r \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\x12\x13\n\x0blastModelID\x18\x0e \x01(\x03\x12\x15\n\rfailureReason\x18\x0f \x01(\t\x12\x16\n\x0e\x66\x61ilureMessage\x18\x10 \x01(\t\x12\x14\n\x0ctrainingRows\x18\x11 \x01(\x05\x12\x13\n\x0btestingRows\x18\x12 \x01(\x05\x12\x16\n\x0evalidationRows\x18\x13 \x01(\x05\x12\x10\n\x08progress\x18\x14 \x01(\x05\x12^\n\x10trainingDataHash\x18\x16 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.DataHashes\x12\x13\n\x0btriggeredBy\x18\x17 \x01(\t\x12K\n\x04logs\x18\x18 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Logs\x12\x66\n\x12\x66\x65\x61tureEngineering\x18\x19 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.StudyPhaseStatus\x12\\\n\x08\x62\x61seline\x18\x1a \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.StudyPhaseStatus\x12Z\n\x06search\x18\x1b \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.StudyPhaseStatus\x12\\\n\x08\x65nsemble\x18\x1c \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.StudyPhaseStatus\x12X\n\x04test\x18\x1d \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.StudyPhaseStatus\x12[\n\x07\x65xplain\x18\x1e \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.StudyPhaseStatus\x12\x65\n\x0e\x64riftDetection\x18\x1f \x01(\x0b\x32M.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.DriftDetectorStatus\x12?\n\x0blastUpdated\x18  \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12`\n\x06\x62\x65stFE\x18! \x01(\x0b\x32P.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.FeatureEngineeringSpec\x12]\n\x02gc\x18\" \x01(\x0b\x32Q.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.GarbageCollectionStatus\x12\\\n\nconditions\x18# \x03(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.StudyCondition\"\x7f\n\x18SuccessiveHalvingOptions\x12\x14\n\x0cminResources\x18\x01 \x01(\x05\x12\x17\n\x0freductionFactor\x18\x02 \x01(\x05\x12\x1c\n\x14minEarlyStoppingRate\x18\x03 \x01(\x05\x12\x16\n\x0e\x62ootstrapCount\x18\x04 \x01(\x05\"h\n\x15SuccessiveHalvingSpec\x12\x0e\n\x06\x62udget\x18\x01 \x01(\x05\x12\x0f\n\x07\x62racket\x18\x02 \x01(\x05\x12\x0c\n\x04rung\x18\x03 \x01(\x05\x12\x0e\n\x06\x63onfID\x18\x04 \x01(\x05\x12\x10\n\x08modality\x18\x1a \x01(\t\"\xad\x01\n\x10TextPipelineSpec\x12\x0f\n\x07\x65ncoder\x18\x01 \x01(\t\x12\x11\n\ttokenizer\x18\x02 \x01(\t\x12\x11\n\tstopwords\x18\x03 \x01(\x08\x12\x0b\n\x03pos\x18\x04 \x01(\x08\x12\r\n\x05lemma\x18\x05 \x01(\x08\x12\x0c\n\x04stem\x18\x06 \x01(\x08\x12\x11\n\tembedding\x18\x07 \x01(\t\x12\x0b\n\x03svd\x18\x08 \x01(\x08\x12\x18\n\x10maxSvdComponents\x18\t \x01(\x05\"b\n\x16ThresholdPrunerOptions\x12\r\n\x05lower\x18\x01 \x01(\x01\x12\r\n\x05upper\x18\x02 \x01(\x01\x12\x13\n\x0bwarmupSteps\x18\x03 \x01(\x05\x12\x15\n\rintervalSteps\x18\x04 \x01(\x05\"\xff\x08\n\x12TimeSeriesDataSpec\x12\x12\n\ntimeColumn\x18\x01 \x01(\t\x12\x14\n\x0ctargetColumn\x18\x02 \x01(\t\x12\x16\n\x0e\x64\x61tetimeFormat\x18\x03 \x01(\t\x12Z\n\thierarchy\x18\x04 \x01(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.HierarchySpec\x12V\n\x07holiday\x18\x05 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.HolidaySpec\x12U\n\x07history\x18\x06 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.PeriodSpec\x12V\n\x08\x66orecast\x18\x07 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.PeriodSpec\x12j\n\x11yearlySeasonality\x18\x08 \x01(\x0b\x32O.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.PeriodSeasonalitySpec\x12j\n\x11weeklySeasonality\x18\t \x01(\x0b\x32O.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.PeriodSeasonalitySpec\x12i\n\x10\x64\x61ilySeasonality\x18\n \x01(\x0b\x32O.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.PeriodSeasonalitySpec\x12\x0e\n\x06growth\x18\r \x01(\t\x12[\n\nregressors\x18\x0e \x03(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.RegressorSpec\x12l\n\x13\x63ustomSeasonalities\x18\x0f \x03(\x0b\x32O.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.CustomSeasonalitySpec\x12_\n\x0c\x63hangepoints\x18\x10 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ChangePointSpec\x12\x14\n\x0cintevalWidth\x18\x11 \x01(\x01\x12\x1a\n\x12uncertaintySamples\x18\x12 \x01(\x05\x12\x13\n\x0bseasonality\x18\x13 \x01(\t\"\x9c\x05\n\x0cTrainingSpec\x12\x33\n\x06labRef\x18\x01 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12\x10\n\x08priority\x18\x02 \x01(\t\x12\x0e\n\x06\x63vtype\x18\x03 \x01(\t\x12\n\n\x02\x63V\x18\x04 \x01(\x08\x12\r\n\x05\x66olds\x18\x05 \x01(\x05\x12V\n\x05split\x18\x06 \x01(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.DataSplitSpec\x12\x13\n\x0b\x65valMetrics\x18\x07 \x03(\t\x12[\n\x02sh\x18\n \x01(\x0b\x32O.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.SuccessiveHalvingSpec\x12\x0c\n\x04seed\x18\x0b \x01(\x01\x12X\n\tresources\x18\x0c \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ResourceSpec\x12\x0b\n\x03gpu\x18\r \x01(\x08\x12\x13\n\x0b\x64istributed\x18\x0e \x01(\x08\x12\x19\n\x11\x66\x65\x61tureImportance\x18\x0f \x01(\x08\x12\x11\n\tnodeCount\x18\x10 \x01(\x05\x12\x11\n\tsamplePct\x18\x11 \x01(\x05\x12\\\n\ncheckpoint\x18\x12 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.CheckpointSpec\x12\x10\n\x08logLevel\x18\x13 \x01(\t\x12\x15\n\rtimeoutInSecs\x18\x14 \x01(\x05\"f\n\x11TrainingStageSpec\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x14\n\x0cnotebookName\x18\x02 \x01(\t\x12\x0f\n\x07labName\x18\x03 \x01(\t\x12\x19\n\x11studyTemplateName\x18\x04 \x01(\t\"\xe6\x01\n\x0cUATStageSpec\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x17\n\x0fservingSiteName\x18\x02 \x01(\t\x12R\n\x05tests\x18\x03 \x03(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelTest\x12X\n\tresources\x18\x04 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ResourceSpec\"\'\n\x11VideoPipelineSpec\x12\x12\n\nfeaturizer\x18\x01 \x01(\tB:Z8github.com/metaprov/modelaapi/pkg/apis/training/v1alpha1')



_ALGORITHMSEARCHSPACESPEC = DESCRIPTOR.message_types_by_name['AlgorithmSearchSpaceSpec']
_AUDIOPIPELINESPEC = DESCRIPTOR.message_types_by_name['AudioPipelineSpec']
_BACKTESTSPEC = DESCRIPTOR.message_types_by_name['BacktestSpec']
_BASELINESPEC = DESCRIPTOR.message_types_by_name['BaselineSpec']
_CAPACITYSTAGESPEC = DESCRIPTOR.message_types_by_name['CapacityStageSpec']
_CHANGEPOINTSPEC = DESCRIPTOR.message_types_by_name['ChangePointSpec']
_CHATBOTESTIMATORSPEC = DESCRIPTOR.message_types_by_name['ChatbotEstimatorSpec']
_CHECKPOINTSPEC = DESCRIPTOR.message_types_by_name['CheckpointSpec']
_CLASSICALESTIMATORSPEC = DESCRIPTOR.message_types_by_name['ClassicalEstimatorSpec']
_CRONREPORT = DESCRIPTOR.message_types_by_name['CronReport']
_CRONREPORTCONDITION = DESCRIPTOR.message_types_by_name['CronReportCondition']
_CRONREPORTLIST = DESCRIPTOR.message_types_by_name['CronReportList']
_CRONREPORTSPEC = DESCRIPTOR.message_types_by_name['CronReportSpec']
_CRONREPORTSTATUS = DESCRIPTOR.message_types_by_name['CronReportStatus']
_CUSTOMREPORTSPEC = DESCRIPTOR.message_types_by_name['CustomReportSpec']
_CUSTOMSEASONALITYSPEC = DESCRIPTOR.message_types_by_name['CustomSeasonalitySpec']
_DATAHASHES = DESCRIPTOR.message_types_by_name['DataHashes']
_DATASPLITSPEC = DESCRIPTOR.message_types_by_name['DataSplitSpec']
_DATASTAGESPEC = DESCRIPTOR.message_types_by_name['DataStageSpec']
_DEEPESTIMATORLAYER = DESCRIPTOR.message_types_by_name['DeepEstimatorLayer']
_DEEPESTIMATORSPEC = DESCRIPTOR.message_types_by_name['DeepEstimatorSpec']
_DEPLOYMENTSTAGESPEC = DESCRIPTOR.message_types_by_name['DeploymentStageSpec']
_DRIFTDETECTIONSPEC = DESCRIPTOR.message_types_by_name['DriftDetectionSpec']
_DRIFTDETECTORSTATUS = DESCRIPTOR.message_types_by_name['DriftDetectorStatus']
_EARLYSTOPSPEC = DESCRIPTOR.message_types_by_name['EarlyStopSpec']
_ENSEMBLERULES = DESCRIPTOR.message_types_by_name['EnsembleRules']
_ENSEMBLESPEC = DESCRIPTOR.message_types_by_name['EnsembleSpec']
_ENSEMBLESSPEC = DESCRIPTOR.message_types_by_name['EnsemblesSpec']
_FEATUREENGINEERINGPIPELINE = DESCRIPTOR.message_types_by_name['FeatureEngineeringPipeline']
_FEATUREENGINEERINGSEARCHSPEC = DESCRIPTOR.message_types_by_name['FeatureEngineeringSearchSpec']
_FEATUREENGINEERINGSEARCHSTATUS = DESCRIPTOR.message_types_by_name['FeatureEngineeringSearchStatus']
_FEATUREENGINEERINGSPEC = DESCRIPTOR.message_types_by_name['FeatureEngineeringSpec']
_FEATUREIMPORTANCE = DESCRIPTOR.message_types_by_name['FeatureImportance']
_FEATUREINFO = DESCRIPTOR.message_types_by_name['FeatureInfo']
_FEATUREPAIR = DESCRIPTOR.message_types_by_name['FeaturePair']
_FEATURESELECTIONSPEC = DESCRIPTOR.message_types_by_name['FeatureSelectionSpec']
_FORECASTOBJ = DESCRIPTOR.message_types_by_name['ForecastObj']
_FORECASTPOSTPROCESSINGSPEC = DESCRIPTOR.message_types_by_name['ForecastPostProcessingSpec']
_FORECASTSPEC = DESCRIPTOR.message_types_by_name['ForecastSpec']
_GARBAGECOLLECTIONSPEC = DESCRIPTOR.message_types_by_name['GarbageCollectionSpec']
_GARBAGECOLLECTIONSTATUS = DESCRIPTOR.message_types_by_name['GarbageCollectionStatus']
_GENERATEDCOLUMNSPEC = DESCRIPTOR.message_types_by_name['GeneratedColumnSpec']
_HIERARCHY = DESCRIPTOR.message_types_by_name['Hierarchy']
_HIERARCHYSPEC = DESCRIPTOR.message_types_by_name['HierarchySpec']
_HOLIDAYSPEC = DESCRIPTOR.message_types_by_name['HolidaySpec']
_HYPERPARAMETERVALUE = DESCRIPTOR.message_types_by_name['HyperParameterValue']
_HYPERBANDOPTIONS = DESCRIPTOR.message_types_by_name['HyperbandOptions']
_IMAGEPIPELINESPEC = DESCRIPTOR.message_types_by_name['ImagePipelineSpec']
_IMBALANCEHANDLINGSPEC = DESCRIPTOR.message_types_by_name['ImbalanceHandlingSpec']
_INTERPRETABILITYSPEC = DESCRIPTOR.message_types_by_name['InterpretabilitySpec']
_INTERPRETABILITYSTATUS = DESCRIPTOR.message_types_by_name['InterpretabilityStatus']
_LEVEL = DESCRIPTOR.message_types_by_name['Level']
_MEDIANPRUNEROPTIONS = DESCRIPTOR.message_types_by_name['MedianPrunerOptions']
_MODEL = DESCRIPTOR.message_types_by_name['Model']
_MODELAUTOBUILDER = DESCRIPTOR.message_types_by_name['ModelAutobuilder']
_MODELAUTOBUILDERCONDITION = DESCRIPTOR.message_types_by_name['ModelAutobuilderCondition']
_MODELAUTOBUILDERLIST = DESCRIPTOR.message_types_by_name['ModelAutobuilderList']
_MODELAUTOBUILDERSPEC = DESCRIPTOR.message_types_by_name['ModelAutobuilderSpec']
_MODELAUTOBUILDERSTATUS = DESCRIPTOR.message_types_by_name['ModelAutobuilderStatus']
_MODELCOMPILERRUN = DESCRIPTOR.message_types_by_name['ModelCompilerRun']
_MODELCOMPILERRUNCONDITION = DESCRIPTOR.message_types_by_name['ModelCompilerRunCondition']
_MODELCOMPILERRUNLIST = DESCRIPTOR.message_types_by_name['ModelCompilerRunList']
_MODELCOMPILERRUNSPEC = DESCRIPTOR.message_types_by_name['ModelCompilerRunSpec']
_MODELCOMPILERRUNSTATUS = DESCRIPTOR.message_types_by_name['ModelCompilerRunStatus']
_MODELCONDITION = DESCRIPTOR.message_types_by_name['ModelCondition']
_MODELIMAGESPEC = DESCRIPTOR.message_types_by_name['ModelImageSpec']
_MODELLIST = DESCRIPTOR.message_types_by_name['ModelList']
_MODELPIPELINE = DESCRIPTOR.message_types_by_name['ModelPipeline']
_MODELPIPELINECONDITION = DESCRIPTOR.message_types_by_name['ModelPipelineCondition']
_MODELPIPELINELIST = DESCRIPTOR.message_types_by_name['ModelPipelineList']
_MODELPIPELINERUN = DESCRIPTOR.message_types_by_name['ModelPipelineRun']
_MODELPIPELINERUNCONDITION = DESCRIPTOR.message_types_by_name['ModelPipelineRunCondition']
_MODELPIPELINERUNLIST = DESCRIPTOR.message_types_by_name['ModelPipelineRunList']
_MODELPIPELINERUNSPEC = DESCRIPTOR.message_types_by_name['ModelPipelineRunSpec']
_MODELPIPELINERUNSTAGESTATUS = DESCRIPTOR.message_types_by_name['ModelPipelineRunStageStatus']
_MODELPIPELINERUNSTATUS = DESCRIPTOR.message_types_by_name['ModelPipelineRunStatus']
_MODELPIPELINESPEC = DESCRIPTOR.message_types_by_name['ModelPipelineSpec']
_MODELPIPELINESPEC_DATASETSELECTORENTRY = _MODELPIPELINESPEC.nested_types_by_name['DatasetSelectorEntry']
_MODELPIPELINESTATUS = DESCRIPTOR.message_types_by_name['ModelPipelineStatus']
_MODELRESULT = DESCRIPTOR.message_types_by_name['ModelResult']
_MODELSPEC = DESCRIPTOR.message_types_by_name['ModelSpec']
_MODELSTATUS = DESCRIPTOR.message_types_by_name['ModelStatus']
_MODELTEST = DESCRIPTOR.message_types_by_name['ModelTest']
_MODELTESTRESULT = DESCRIPTOR.message_types_by_name['ModelTestResult']
_NLPESTIMATORSPEC = DESCRIPTOR.message_types_by_name['NLPEstimatorSpec']
_NNLAYERPARAMETER = DESCRIPTOR.message_types_by_name['NNLayerParameter']
_NOTEBOOK = DESCRIPTOR.message_types_by_name['Notebook']
_NOTEBOOKCONDITION = DESCRIPTOR.message_types_by_name['NotebookCondition']
_NOTEBOOKLIST = DESCRIPTOR.message_types_by_name['NotebookList']
_NOTEBOOKRUN = DESCRIPTOR.message_types_by_name['NotebookRun']
_NOTEBOOKRUNCONDITION = DESCRIPTOR.message_types_by_name['NotebookRunCondition']
_NOTEBOOKRUNLIST = DESCRIPTOR.message_types_by_name['NotebookRunList']
_NOTEBOOKRUNSPEC = DESCRIPTOR.message_types_by_name['NotebookRunSpec']
_NOTEBOOKRUNSTATUS = DESCRIPTOR.message_types_by_name['NotebookRunStatus']
_NOTEBOOKSPEC = DESCRIPTOR.message_types_by_name['NotebookSpec']
_NOTEBOOKSTATUS = DESCRIPTOR.message_types_by_name['NotebookStatus']
_NOTEBOOKVARVALUE = DESCRIPTOR.message_types_by_name['NotebookVarValue']
_PERCENTILEPRUNEROPTIONS = DESCRIPTOR.message_types_by_name['PercentilePrunerOptions']
_PERIODSEASONALITYSPEC = DESCRIPTOR.message_types_by_name['PeriodSeasonalitySpec']
_PERIODSPEC = DESCRIPTOR.message_types_by_name['PeriodSpec']
_PRUNERSPEC = DESCRIPTOR.message_types_by_name['PrunerSpec']
_REGRESSORSPEC = DESCRIPTOR.message_types_by_name['RegressorSpec']
_RELEASESTAGESPEC = DESCRIPTOR.message_types_by_name['ReleaseStageSpec']
_REPORT = DESCRIPTOR.message_types_by_name['Report']
_REPORTCONDITION = DESCRIPTOR.message_types_by_name['ReportCondition']
_REPORTLIST = DESCRIPTOR.message_types_by_name['ReportList']
_REPORTSPEC = DESCRIPTOR.message_types_by_name['ReportSpec']
_REPORTSTATUS = DESCRIPTOR.message_types_by_name['ReportStatus']
_REPORTTEMPLATE = DESCRIPTOR.message_types_by_name['ReportTemplate']
_RESOURCECONSUMPTION = DESCRIPTOR.message_types_by_name['ResourceConsumption']
_RUNTIMESTATUS = DESCRIPTOR.message_types_by_name['RuntimeStatus']
_RUNTIMESTATUS_PYTHONPACKAGESENTRY = _RUNTIMESTATUS.nested_types_by_name['PythonPackagesEntry']
_SEARCHSPEC = DESCRIPTOR.message_types_by_name['SearchSpec']
_SEGMENTSPEC = DESCRIPTOR.message_types_by_name['SegmentSpec']
_SERVINGSPEC = DESCRIPTOR.message_types_by_name['ServingSpec']
_STUDY = DESCRIPTOR.message_types_by_name['Study']
_STUDYCONDITION = DESCRIPTOR.message_types_by_name['StudyCondition']
_STUDYFORECASTSPEC = DESCRIPTOR.message_types_by_name['StudyForecastSpec']
_STUDYLIST = DESCRIPTOR.message_types_by_name['StudyList']
_STUDYPHASESTATUS = DESCRIPTOR.message_types_by_name['StudyPhaseStatus']
_STUDYSCHEDULESPEC = DESCRIPTOR.message_types_by_name['StudyScheduleSpec']
_STUDYSPEC = DESCRIPTOR.message_types_by_name['StudySpec']
_STUDYSTATUS = DESCRIPTOR.message_types_by_name['StudyStatus']
_SUCCESSIVEHALVINGOPTIONS = DESCRIPTOR.message_types_by_name['SuccessiveHalvingOptions']
_SUCCESSIVEHALVINGSPEC = DESCRIPTOR.message_types_by_name['SuccessiveHalvingSpec']
_TEXTPIPELINESPEC = DESCRIPTOR.message_types_by_name['TextPipelineSpec']
_THRESHOLDPRUNEROPTIONS = DESCRIPTOR.message_types_by_name['ThresholdPrunerOptions']
_TIMESERIESDATASPEC = DESCRIPTOR.message_types_by_name['TimeSeriesDataSpec']
_TRAININGSPEC = DESCRIPTOR.message_types_by_name['TrainingSpec']
_TRAININGSTAGESPEC = DESCRIPTOR.message_types_by_name['TrainingStageSpec']
_UATSTAGESPEC = DESCRIPTOR.message_types_by_name['UATStageSpec']
_VIDEOPIPELINESPEC = DESCRIPTOR.message_types_by_name['VideoPipelineSpec']
AlgorithmSearchSpaceSpec = _reflection.GeneratedProtocolMessageType('AlgorithmSearchSpaceSpec', (_message.Message,), {
  'DESCRIPTOR' : _ALGORITHMSEARCHSPACESPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.AlgorithmSearchSpaceSpec)
  })
_sym_db.RegisterMessage(AlgorithmSearchSpaceSpec)

AudioPipelineSpec = _reflection.GeneratedProtocolMessageType('AudioPipelineSpec', (_message.Message,), {
  'DESCRIPTOR' : _AUDIOPIPELINESPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.AudioPipelineSpec)
  })
_sym_db.RegisterMessage(AudioPipelineSpec)

BacktestSpec = _reflection.GeneratedProtocolMessageType('BacktestSpec', (_message.Message,), {
  'DESCRIPTOR' : _BACKTESTSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.BacktestSpec)
  })
_sym_db.RegisterMessage(BacktestSpec)

BaselineSpec = _reflection.GeneratedProtocolMessageType('BaselineSpec', (_message.Message,), {
  'DESCRIPTOR' : _BASELINESPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.BaselineSpec)
  })
_sym_db.RegisterMessage(BaselineSpec)

CapacityStageSpec = _reflection.GeneratedProtocolMessageType('CapacityStageSpec', (_message.Message,), {
  'DESCRIPTOR' : _CAPACITYSTAGESPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.CapacityStageSpec)
  })
_sym_db.RegisterMessage(CapacityStageSpec)

ChangePointSpec = _reflection.GeneratedProtocolMessageType('ChangePointSpec', (_message.Message,), {
  'DESCRIPTOR' : _CHANGEPOINTSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ChangePointSpec)
  })
_sym_db.RegisterMessage(ChangePointSpec)

ChatbotEstimatorSpec = _reflection.GeneratedProtocolMessageType('ChatbotEstimatorSpec', (_message.Message,), {
  'DESCRIPTOR' : _CHATBOTESTIMATORSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ChatbotEstimatorSpec)
  })
_sym_db.RegisterMessage(ChatbotEstimatorSpec)

CheckpointSpec = _reflection.GeneratedProtocolMessageType('CheckpointSpec', (_message.Message,), {
  'DESCRIPTOR' : _CHECKPOINTSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.CheckpointSpec)
  })
_sym_db.RegisterMessage(CheckpointSpec)

ClassicalEstimatorSpec = _reflection.GeneratedProtocolMessageType('ClassicalEstimatorSpec', (_message.Message,), {
  'DESCRIPTOR' : _CLASSICALESTIMATORSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ClassicalEstimatorSpec)
  })
_sym_db.RegisterMessage(ClassicalEstimatorSpec)

CronReport = _reflection.GeneratedProtocolMessageType('CronReport', (_message.Message,), {
  'DESCRIPTOR' : _CRONREPORT,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.CronReport)
  })
_sym_db.RegisterMessage(CronReport)

CronReportCondition = _reflection.GeneratedProtocolMessageType('CronReportCondition', (_message.Message,), {
  'DESCRIPTOR' : _CRONREPORTCONDITION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.CronReportCondition)
  })
_sym_db.RegisterMessage(CronReportCondition)

CronReportList = _reflection.GeneratedProtocolMessageType('CronReportList', (_message.Message,), {
  'DESCRIPTOR' : _CRONREPORTLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.CronReportList)
  })
_sym_db.RegisterMessage(CronReportList)

CronReportSpec = _reflection.GeneratedProtocolMessageType('CronReportSpec', (_message.Message,), {
  'DESCRIPTOR' : _CRONREPORTSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.CronReportSpec)
  })
_sym_db.RegisterMessage(CronReportSpec)

CronReportStatus = _reflection.GeneratedProtocolMessageType('CronReportStatus', (_message.Message,), {
  'DESCRIPTOR' : _CRONREPORTSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.CronReportStatus)
  })
_sym_db.RegisterMessage(CronReportStatus)

CustomReportSpec = _reflection.GeneratedProtocolMessageType('CustomReportSpec', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMREPORTSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.CustomReportSpec)
  })
_sym_db.RegisterMessage(CustomReportSpec)

CustomSeasonalitySpec = _reflection.GeneratedProtocolMessageType('CustomSeasonalitySpec', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMSEASONALITYSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.CustomSeasonalitySpec)
  })
_sym_db.RegisterMessage(CustomSeasonalitySpec)

DataHashes = _reflection.GeneratedProtocolMessageType('DataHashes', (_message.Message,), {
  'DESCRIPTOR' : _DATAHASHES,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.DataHashes)
  })
_sym_db.RegisterMessage(DataHashes)

DataSplitSpec = _reflection.GeneratedProtocolMessageType('DataSplitSpec', (_message.Message,), {
  'DESCRIPTOR' : _DATASPLITSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.DataSplitSpec)
  })
_sym_db.RegisterMessage(DataSplitSpec)

DataStageSpec = _reflection.GeneratedProtocolMessageType('DataStageSpec', (_message.Message,), {
  'DESCRIPTOR' : _DATASTAGESPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.DataStageSpec)
  })
_sym_db.RegisterMessage(DataStageSpec)

DeepEstimatorLayer = _reflection.GeneratedProtocolMessageType('DeepEstimatorLayer', (_message.Message,), {
  'DESCRIPTOR' : _DEEPESTIMATORLAYER,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.DeepEstimatorLayer)
  })
_sym_db.RegisterMessage(DeepEstimatorLayer)

DeepEstimatorSpec = _reflection.GeneratedProtocolMessageType('DeepEstimatorSpec', (_message.Message,), {
  'DESCRIPTOR' : _DEEPESTIMATORSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.DeepEstimatorSpec)
  })
_sym_db.RegisterMessage(DeepEstimatorSpec)

DeploymentStageSpec = _reflection.GeneratedProtocolMessageType('DeploymentStageSpec', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYMENTSTAGESPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.DeploymentStageSpec)
  })
_sym_db.RegisterMessage(DeploymentStageSpec)

DriftDetectionSpec = _reflection.GeneratedProtocolMessageType('DriftDetectionSpec', (_message.Message,), {
  'DESCRIPTOR' : _DRIFTDETECTIONSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.DriftDetectionSpec)
  })
_sym_db.RegisterMessage(DriftDetectionSpec)

DriftDetectorStatus = _reflection.GeneratedProtocolMessageType('DriftDetectorStatus', (_message.Message,), {
  'DESCRIPTOR' : _DRIFTDETECTORSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.DriftDetectorStatus)
  })
_sym_db.RegisterMessage(DriftDetectorStatus)

EarlyStopSpec = _reflection.GeneratedProtocolMessageType('EarlyStopSpec', (_message.Message,), {
  'DESCRIPTOR' : _EARLYSTOPSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.EarlyStopSpec)
  })
_sym_db.RegisterMessage(EarlyStopSpec)

EnsembleRules = _reflection.GeneratedProtocolMessageType('EnsembleRules', (_message.Message,), {
  'DESCRIPTOR' : _ENSEMBLERULES,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.EnsembleRules)
  })
_sym_db.RegisterMessage(EnsembleRules)

EnsembleSpec = _reflection.GeneratedProtocolMessageType('EnsembleSpec', (_message.Message,), {
  'DESCRIPTOR' : _ENSEMBLESPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.EnsembleSpec)
  })
_sym_db.RegisterMessage(EnsembleSpec)

EnsemblesSpec = _reflection.GeneratedProtocolMessageType('EnsemblesSpec', (_message.Message,), {
  'DESCRIPTOR' : _ENSEMBLESSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.EnsemblesSpec)
  })
_sym_db.RegisterMessage(EnsemblesSpec)

FeatureEngineeringPipeline = _reflection.GeneratedProtocolMessageType('FeatureEngineeringPipeline', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREENGINEERINGPIPELINE,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.FeatureEngineeringPipeline)
  })
_sym_db.RegisterMessage(FeatureEngineeringPipeline)

FeatureEngineeringSearchSpec = _reflection.GeneratedProtocolMessageType('FeatureEngineeringSearchSpec', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREENGINEERINGSEARCHSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.FeatureEngineeringSearchSpec)
  })
_sym_db.RegisterMessage(FeatureEngineeringSearchSpec)

FeatureEngineeringSearchStatus = _reflection.GeneratedProtocolMessageType('FeatureEngineeringSearchStatus', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREENGINEERINGSEARCHSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.FeatureEngineeringSearchStatus)
  })
_sym_db.RegisterMessage(FeatureEngineeringSearchStatus)

FeatureEngineeringSpec = _reflection.GeneratedProtocolMessageType('FeatureEngineeringSpec', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREENGINEERINGSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.FeatureEngineeringSpec)
  })
_sym_db.RegisterMessage(FeatureEngineeringSpec)

FeatureImportance = _reflection.GeneratedProtocolMessageType('FeatureImportance', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREIMPORTANCE,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.FeatureImportance)
  })
_sym_db.RegisterMessage(FeatureImportance)

FeatureInfo = _reflection.GeneratedProtocolMessageType('FeatureInfo', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREINFO,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.FeatureInfo)
  })
_sym_db.RegisterMessage(FeatureInfo)

FeaturePair = _reflection.GeneratedProtocolMessageType('FeaturePair', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREPAIR,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.FeaturePair)
  })
_sym_db.RegisterMessage(FeaturePair)

FeatureSelectionSpec = _reflection.GeneratedProtocolMessageType('FeatureSelectionSpec', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESELECTIONSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.FeatureSelectionSpec)
  })
_sym_db.RegisterMessage(FeatureSelectionSpec)

ForecastObj = _reflection.GeneratedProtocolMessageType('ForecastObj', (_message.Message,), {
  'DESCRIPTOR' : _FORECASTOBJ,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ForecastObj)
  })
_sym_db.RegisterMessage(ForecastObj)

ForecastPostProcessingSpec = _reflection.GeneratedProtocolMessageType('ForecastPostProcessingSpec', (_message.Message,), {
  'DESCRIPTOR' : _FORECASTPOSTPROCESSINGSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ForecastPostProcessingSpec)
  })
_sym_db.RegisterMessage(ForecastPostProcessingSpec)

ForecastSpec = _reflection.GeneratedProtocolMessageType('ForecastSpec', (_message.Message,), {
  'DESCRIPTOR' : _FORECASTSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ForecastSpec)
  })
_sym_db.RegisterMessage(ForecastSpec)

GarbageCollectionSpec = _reflection.GeneratedProtocolMessageType('GarbageCollectionSpec', (_message.Message,), {
  'DESCRIPTOR' : _GARBAGECOLLECTIONSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.GarbageCollectionSpec)
  })
_sym_db.RegisterMessage(GarbageCollectionSpec)

GarbageCollectionStatus = _reflection.GeneratedProtocolMessageType('GarbageCollectionStatus', (_message.Message,), {
  'DESCRIPTOR' : _GARBAGECOLLECTIONSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.GarbageCollectionStatus)
  })
_sym_db.RegisterMessage(GarbageCollectionStatus)

GeneratedColumnSpec = _reflection.GeneratedProtocolMessageType('GeneratedColumnSpec', (_message.Message,), {
  'DESCRIPTOR' : _GENERATEDCOLUMNSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.GeneratedColumnSpec)
  })
_sym_db.RegisterMessage(GeneratedColumnSpec)

Hierarchy = _reflection.GeneratedProtocolMessageType('Hierarchy', (_message.Message,), {
  'DESCRIPTOR' : _HIERARCHY,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Hierarchy)
  })
_sym_db.RegisterMessage(Hierarchy)

HierarchySpec = _reflection.GeneratedProtocolMessageType('HierarchySpec', (_message.Message,), {
  'DESCRIPTOR' : _HIERARCHYSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.HierarchySpec)
  })
_sym_db.RegisterMessage(HierarchySpec)

HolidaySpec = _reflection.GeneratedProtocolMessageType('HolidaySpec', (_message.Message,), {
  'DESCRIPTOR' : _HOLIDAYSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.HolidaySpec)
  })
_sym_db.RegisterMessage(HolidaySpec)

HyperParameterValue = _reflection.GeneratedProtocolMessageType('HyperParameterValue', (_message.Message,), {
  'DESCRIPTOR' : _HYPERPARAMETERVALUE,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.HyperParameterValue)
  })
_sym_db.RegisterMessage(HyperParameterValue)

HyperbandOptions = _reflection.GeneratedProtocolMessageType('HyperbandOptions', (_message.Message,), {
  'DESCRIPTOR' : _HYPERBANDOPTIONS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.HyperbandOptions)
  })
_sym_db.RegisterMessage(HyperbandOptions)

ImagePipelineSpec = _reflection.GeneratedProtocolMessageType('ImagePipelineSpec', (_message.Message,), {
  'DESCRIPTOR' : _IMAGEPIPELINESPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ImagePipelineSpec)
  })
_sym_db.RegisterMessage(ImagePipelineSpec)

ImbalanceHandlingSpec = _reflection.GeneratedProtocolMessageType('ImbalanceHandlingSpec', (_message.Message,), {
  'DESCRIPTOR' : _IMBALANCEHANDLINGSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ImbalanceHandlingSpec)
  })
_sym_db.RegisterMessage(ImbalanceHandlingSpec)

InterpretabilitySpec = _reflection.GeneratedProtocolMessageType('InterpretabilitySpec', (_message.Message,), {
  'DESCRIPTOR' : _INTERPRETABILITYSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.InterpretabilitySpec)
  })
_sym_db.RegisterMessage(InterpretabilitySpec)

InterpretabilityStatus = _reflection.GeneratedProtocolMessageType('InterpretabilityStatus', (_message.Message,), {
  'DESCRIPTOR' : _INTERPRETABILITYSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.InterpretabilityStatus)
  })
_sym_db.RegisterMessage(InterpretabilityStatus)

Level = _reflection.GeneratedProtocolMessageType('Level', (_message.Message,), {
  'DESCRIPTOR' : _LEVEL,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Level)
  })
_sym_db.RegisterMessage(Level)

MedianPrunerOptions = _reflection.GeneratedProtocolMessageType('MedianPrunerOptions', (_message.Message,), {
  'DESCRIPTOR' : _MEDIANPRUNEROPTIONS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.MedianPrunerOptions)
  })
_sym_db.RegisterMessage(MedianPrunerOptions)

Model = _reflection.GeneratedProtocolMessageType('Model', (_message.Message,), {
  'DESCRIPTOR' : _MODEL,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model)
  })
_sym_db.RegisterMessage(Model)

ModelAutobuilder = _reflection.GeneratedProtocolMessageType('ModelAutobuilder', (_message.Message,), {
  'DESCRIPTOR' : _MODELAUTOBUILDER,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelAutobuilder)
  })
_sym_db.RegisterMessage(ModelAutobuilder)

ModelAutobuilderCondition = _reflection.GeneratedProtocolMessageType('ModelAutobuilderCondition', (_message.Message,), {
  'DESCRIPTOR' : _MODELAUTOBUILDERCONDITION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelAutobuilderCondition)
  })
_sym_db.RegisterMessage(ModelAutobuilderCondition)

ModelAutobuilderList = _reflection.GeneratedProtocolMessageType('ModelAutobuilderList', (_message.Message,), {
  'DESCRIPTOR' : _MODELAUTOBUILDERLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelAutobuilderList)
  })
_sym_db.RegisterMessage(ModelAutobuilderList)

ModelAutobuilderSpec = _reflection.GeneratedProtocolMessageType('ModelAutobuilderSpec', (_message.Message,), {
  'DESCRIPTOR' : _MODELAUTOBUILDERSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelAutobuilderSpec)
  })
_sym_db.RegisterMessage(ModelAutobuilderSpec)

ModelAutobuilderStatus = _reflection.GeneratedProtocolMessageType('ModelAutobuilderStatus', (_message.Message,), {
  'DESCRIPTOR' : _MODELAUTOBUILDERSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelAutobuilderStatus)
  })
_sym_db.RegisterMessage(ModelAutobuilderStatus)

ModelCompilerRun = _reflection.GeneratedProtocolMessageType('ModelCompilerRun', (_message.Message,), {
  'DESCRIPTOR' : _MODELCOMPILERRUN,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelCompilerRun)
  })
_sym_db.RegisterMessage(ModelCompilerRun)

ModelCompilerRunCondition = _reflection.GeneratedProtocolMessageType('ModelCompilerRunCondition', (_message.Message,), {
  'DESCRIPTOR' : _MODELCOMPILERRUNCONDITION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelCompilerRunCondition)
  })
_sym_db.RegisterMessage(ModelCompilerRunCondition)

ModelCompilerRunList = _reflection.GeneratedProtocolMessageType('ModelCompilerRunList', (_message.Message,), {
  'DESCRIPTOR' : _MODELCOMPILERRUNLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelCompilerRunList)
  })
_sym_db.RegisterMessage(ModelCompilerRunList)

ModelCompilerRunSpec = _reflection.GeneratedProtocolMessageType('ModelCompilerRunSpec', (_message.Message,), {
  'DESCRIPTOR' : _MODELCOMPILERRUNSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelCompilerRunSpec)
  })
_sym_db.RegisterMessage(ModelCompilerRunSpec)

ModelCompilerRunStatus = _reflection.GeneratedProtocolMessageType('ModelCompilerRunStatus', (_message.Message,), {
  'DESCRIPTOR' : _MODELCOMPILERRUNSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelCompilerRunStatus)
  })
_sym_db.RegisterMessage(ModelCompilerRunStatus)

ModelCondition = _reflection.GeneratedProtocolMessageType('ModelCondition', (_message.Message,), {
  'DESCRIPTOR' : _MODELCONDITION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelCondition)
  })
_sym_db.RegisterMessage(ModelCondition)

ModelImageSpec = _reflection.GeneratedProtocolMessageType('ModelImageSpec', (_message.Message,), {
  'DESCRIPTOR' : _MODELIMAGESPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelImageSpec)
  })
_sym_db.RegisterMessage(ModelImageSpec)

ModelList = _reflection.GeneratedProtocolMessageType('ModelList', (_message.Message,), {
  'DESCRIPTOR' : _MODELLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelList)
  })
_sym_db.RegisterMessage(ModelList)

ModelPipeline = _reflection.GeneratedProtocolMessageType('ModelPipeline', (_message.Message,), {
  'DESCRIPTOR' : _MODELPIPELINE,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipeline)
  })
_sym_db.RegisterMessage(ModelPipeline)

ModelPipelineCondition = _reflection.GeneratedProtocolMessageType('ModelPipelineCondition', (_message.Message,), {
  'DESCRIPTOR' : _MODELPIPELINECONDITION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineCondition)
  })
_sym_db.RegisterMessage(ModelPipelineCondition)

ModelPipelineList = _reflection.GeneratedProtocolMessageType('ModelPipelineList', (_message.Message,), {
  'DESCRIPTOR' : _MODELPIPELINELIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineList)
  })
_sym_db.RegisterMessage(ModelPipelineList)

ModelPipelineRun = _reflection.GeneratedProtocolMessageType('ModelPipelineRun', (_message.Message,), {
  'DESCRIPTOR' : _MODELPIPELINERUN,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineRun)
  })
_sym_db.RegisterMessage(ModelPipelineRun)

ModelPipelineRunCondition = _reflection.GeneratedProtocolMessageType('ModelPipelineRunCondition', (_message.Message,), {
  'DESCRIPTOR' : _MODELPIPELINERUNCONDITION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineRunCondition)
  })
_sym_db.RegisterMessage(ModelPipelineRunCondition)

ModelPipelineRunList = _reflection.GeneratedProtocolMessageType('ModelPipelineRunList', (_message.Message,), {
  'DESCRIPTOR' : _MODELPIPELINERUNLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineRunList)
  })
_sym_db.RegisterMessage(ModelPipelineRunList)

ModelPipelineRunSpec = _reflection.GeneratedProtocolMessageType('ModelPipelineRunSpec', (_message.Message,), {
  'DESCRIPTOR' : _MODELPIPELINERUNSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineRunSpec)
  })
_sym_db.RegisterMessage(ModelPipelineRunSpec)

ModelPipelineRunStageStatus = _reflection.GeneratedProtocolMessageType('ModelPipelineRunStageStatus', (_message.Message,), {
  'DESCRIPTOR' : _MODELPIPELINERUNSTAGESTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineRunStageStatus)
  })
_sym_db.RegisterMessage(ModelPipelineRunStageStatus)

ModelPipelineRunStatus = _reflection.GeneratedProtocolMessageType('ModelPipelineRunStatus', (_message.Message,), {
  'DESCRIPTOR' : _MODELPIPELINERUNSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineRunStatus)
  })
_sym_db.RegisterMessage(ModelPipelineRunStatus)

ModelPipelineSpec = _reflection.GeneratedProtocolMessageType('ModelPipelineSpec', (_message.Message,), {

  'DatasetSelectorEntry' : _reflection.GeneratedProtocolMessageType('DatasetSelectorEntry', (_message.Message,), {
    'DESCRIPTOR' : _MODELPIPELINESPEC_DATASETSELECTORENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineSpec.DatasetSelectorEntry)
    })
  ,
  'DESCRIPTOR' : _MODELPIPELINESPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineSpec)
  })
_sym_db.RegisterMessage(ModelPipelineSpec)
_sym_db.RegisterMessage(ModelPipelineSpec.DatasetSelectorEntry)

ModelPipelineStatus = _reflection.GeneratedProtocolMessageType('ModelPipelineStatus', (_message.Message,), {
  'DESCRIPTOR' : _MODELPIPELINESTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineStatus)
  })
_sym_db.RegisterMessage(ModelPipelineStatus)

ModelResult = _reflection.GeneratedProtocolMessageType('ModelResult', (_message.Message,), {
  'DESCRIPTOR' : _MODELRESULT,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelResult)
  })
_sym_db.RegisterMessage(ModelResult)

ModelSpec = _reflection.GeneratedProtocolMessageType('ModelSpec', (_message.Message,), {
  'DESCRIPTOR' : _MODELSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelSpec)
  })
_sym_db.RegisterMessage(ModelSpec)

ModelStatus = _reflection.GeneratedProtocolMessageType('ModelStatus', (_message.Message,), {
  'DESCRIPTOR' : _MODELSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelStatus)
  })
_sym_db.RegisterMessage(ModelStatus)

ModelTest = _reflection.GeneratedProtocolMessageType('ModelTest', (_message.Message,), {
  'DESCRIPTOR' : _MODELTEST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelTest)
  })
_sym_db.RegisterMessage(ModelTest)

ModelTestResult = _reflection.GeneratedProtocolMessageType('ModelTestResult', (_message.Message,), {
  'DESCRIPTOR' : _MODELTESTRESULT,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelTestResult)
  })
_sym_db.RegisterMessage(ModelTestResult)

NLPEstimatorSpec = _reflection.GeneratedProtocolMessageType('NLPEstimatorSpec', (_message.Message,), {
  'DESCRIPTOR' : _NLPESTIMATORSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NLPEstimatorSpec)
  })
_sym_db.RegisterMessage(NLPEstimatorSpec)

NNLayerParameter = _reflection.GeneratedProtocolMessageType('NNLayerParameter', (_message.Message,), {
  'DESCRIPTOR' : _NNLAYERPARAMETER,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NNLayerParameter)
  })
_sym_db.RegisterMessage(NNLayerParameter)

Notebook = _reflection.GeneratedProtocolMessageType('Notebook', (_message.Message,), {
  'DESCRIPTOR' : _NOTEBOOK,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Notebook)
  })
_sym_db.RegisterMessage(Notebook)

NotebookCondition = _reflection.GeneratedProtocolMessageType('NotebookCondition', (_message.Message,), {
  'DESCRIPTOR' : _NOTEBOOKCONDITION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NotebookCondition)
  })
_sym_db.RegisterMessage(NotebookCondition)

NotebookList = _reflection.GeneratedProtocolMessageType('NotebookList', (_message.Message,), {
  'DESCRIPTOR' : _NOTEBOOKLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NotebookList)
  })
_sym_db.RegisterMessage(NotebookList)

NotebookRun = _reflection.GeneratedProtocolMessageType('NotebookRun', (_message.Message,), {
  'DESCRIPTOR' : _NOTEBOOKRUN,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NotebookRun)
  })
_sym_db.RegisterMessage(NotebookRun)

NotebookRunCondition = _reflection.GeneratedProtocolMessageType('NotebookRunCondition', (_message.Message,), {
  'DESCRIPTOR' : _NOTEBOOKRUNCONDITION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NotebookRunCondition)
  })
_sym_db.RegisterMessage(NotebookRunCondition)

NotebookRunList = _reflection.GeneratedProtocolMessageType('NotebookRunList', (_message.Message,), {
  'DESCRIPTOR' : _NOTEBOOKRUNLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NotebookRunList)
  })
_sym_db.RegisterMessage(NotebookRunList)

NotebookRunSpec = _reflection.GeneratedProtocolMessageType('NotebookRunSpec', (_message.Message,), {
  'DESCRIPTOR' : _NOTEBOOKRUNSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NotebookRunSpec)
  })
_sym_db.RegisterMessage(NotebookRunSpec)

NotebookRunStatus = _reflection.GeneratedProtocolMessageType('NotebookRunStatus', (_message.Message,), {
  'DESCRIPTOR' : _NOTEBOOKRUNSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NotebookRunStatus)
  })
_sym_db.RegisterMessage(NotebookRunStatus)

NotebookSpec = _reflection.GeneratedProtocolMessageType('NotebookSpec', (_message.Message,), {
  'DESCRIPTOR' : _NOTEBOOKSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NotebookSpec)
  })
_sym_db.RegisterMessage(NotebookSpec)

NotebookStatus = _reflection.GeneratedProtocolMessageType('NotebookStatus', (_message.Message,), {
  'DESCRIPTOR' : _NOTEBOOKSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NotebookStatus)
  })
_sym_db.RegisterMessage(NotebookStatus)

NotebookVarValue = _reflection.GeneratedProtocolMessageType('NotebookVarValue', (_message.Message,), {
  'DESCRIPTOR' : _NOTEBOOKVARVALUE,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NotebookVarValue)
  })
_sym_db.RegisterMessage(NotebookVarValue)

PercentilePrunerOptions = _reflection.GeneratedProtocolMessageType('PercentilePrunerOptions', (_message.Message,), {
  'DESCRIPTOR' : _PERCENTILEPRUNEROPTIONS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.PercentilePrunerOptions)
  })
_sym_db.RegisterMessage(PercentilePrunerOptions)

PeriodSeasonalitySpec = _reflection.GeneratedProtocolMessageType('PeriodSeasonalitySpec', (_message.Message,), {
  'DESCRIPTOR' : _PERIODSEASONALITYSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.PeriodSeasonalitySpec)
  })
_sym_db.RegisterMessage(PeriodSeasonalitySpec)

PeriodSpec = _reflection.GeneratedProtocolMessageType('PeriodSpec', (_message.Message,), {
  'DESCRIPTOR' : _PERIODSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.PeriodSpec)
  })
_sym_db.RegisterMessage(PeriodSpec)

PrunerSpec = _reflection.GeneratedProtocolMessageType('PrunerSpec', (_message.Message,), {
  'DESCRIPTOR' : _PRUNERSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.PrunerSpec)
  })
_sym_db.RegisterMessage(PrunerSpec)

RegressorSpec = _reflection.GeneratedProtocolMessageType('RegressorSpec', (_message.Message,), {
  'DESCRIPTOR' : _REGRESSORSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.RegressorSpec)
  })
_sym_db.RegisterMessage(RegressorSpec)

ReleaseStageSpec = _reflection.GeneratedProtocolMessageType('ReleaseStageSpec', (_message.Message,), {
  'DESCRIPTOR' : _RELEASESTAGESPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ReleaseStageSpec)
  })
_sym_db.RegisterMessage(ReleaseStageSpec)

Report = _reflection.GeneratedProtocolMessageType('Report', (_message.Message,), {
  'DESCRIPTOR' : _REPORT,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Report)
  })
_sym_db.RegisterMessage(Report)

ReportCondition = _reflection.GeneratedProtocolMessageType('ReportCondition', (_message.Message,), {
  'DESCRIPTOR' : _REPORTCONDITION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ReportCondition)
  })
_sym_db.RegisterMessage(ReportCondition)

ReportList = _reflection.GeneratedProtocolMessageType('ReportList', (_message.Message,), {
  'DESCRIPTOR' : _REPORTLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ReportList)
  })
_sym_db.RegisterMessage(ReportList)

ReportSpec = _reflection.GeneratedProtocolMessageType('ReportSpec', (_message.Message,), {
  'DESCRIPTOR' : _REPORTSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ReportSpec)
  })
_sym_db.RegisterMessage(ReportSpec)

ReportStatus = _reflection.GeneratedProtocolMessageType('ReportStatus', (_message.Message,), {
  'DESCRIPTOR' : _REPORTSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ReportStatus)
  })
_sym_db.RegisterMessage(ReportStatus)

ReportTemplate = _reflection.GeneratedProtocolMessageType('ReportTemplate', (_message.Message,), {
  'DESCRIPTOR' : _REPORTTEMPLATE,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ReportTemplate)
  })
_sym_db.RegisterMessage(ReportTemplate)

ResourceConsumption = _reflection.GeneratedProtocolMessageType('ResourceConsumption', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCECONSUMPTION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ResourceConsumption)
  })
_sym_db.RegisterMessage(ResourceConsumption)

RuntimeStatus = _reflection.GeneratedProtocolMessageType('RuntimeStatus', (_message.Message,), {

  'PythonPackagesEntry' : _reflection.GeneratedProtocolMessageType('PythonPackagesEntry', (_message.Message,), {
    'DESCRIPTOR' : _RUNTIMESTATUS_PYTHONPACKAGESENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.RuntimeStatus.PythonPackagesEntry)
    })
  ,
  'DESCRIPTOR' : _RUNTIMESTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.RuntimeStatus)
  })
_sym_db.RegisterMessage(RuntimeStatus)
_sym_db.RegisterMessage(RuntimeStatus.PythonPackagesEntry)

SearchSpec = _reflection.GeneratedProtocolMessageType('SearchSpec', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.SearchSpec)
  })
_sym_db.RegisterMessage(SearchSpec)

SegmentSpec = _reflection.GeneratedProtocolMessageType('SegmentSpec', (_message.Message,), {
  'DESCRIPTOR' : _SEGMENTSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.SegmentSpec)
  })
_sym_db.RegisterMessage(SegmentSpec)

ServingSpec = _reflection.GeneratedProtocolMessageType('ServingSpec', (_message.Message,), {
  'DESCRIPTOR' : _SERVINGSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ServingSpec)
  })
_sym_db.RegisterMessage(ServingSpec)

Study = _reflection.GeneratedProtocolMessageType('Study', (_message.Message,), {
  'DESCRIPTOR' : _STUDY,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study)
  })
_sym_db.RegisterMessage(Study)

StudyCondition = _reflection.GeneratedProtocolMessageType('StudyCondition', (_message.Message,), {
  'DESCRIPTOR' : _STUDYCONDITION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.StudyCondition)
  })
_sym_db.RegisterMessage(StudyCondition)

StudyForecastSpec = _reflection.GeneratedProtocolMessageType('StudyForecastSpec', (_message.Message,), {
  'DESCRIPTOR' : _STUDYFORECASTSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.StudyForecastSpec)
  })
_sym_db.RegisterMessage(StudyForecastSpec)

StudyList = _reflection.GeneratedProtocolMessageType('StudyList', (_message.Message,), {
  'DESCRIPTOR' : _STUDYLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.StudyList)
  })
_sym_db.RegisterMessage(StudyList)

StudyPhaseStatus = _reflection.GeneratedProtocolMessageType('StudyPhaseStatus', (_message.Message,), {
  'DESCRIPTOR' : _STUDYPHASESTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.StudyPhaseStatus)
  })
_sym_db.RegisterMessage(StudyPhaseStatus)

StudyScheduleSpec = _reflection.GeneratedProtocolMessageType('StudyScheduleSpec', (_message.Message,), {
  'DESCRIPTOR' : _STUDYSCHEDULESPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.StudyScheduleSpec)
  })
_sym_db.RegisterMessage(StudyScheduleSpec)

StudySpec = _reflection.GeneratedProtocolMessageType('StudySpec', (_message.Message,), {
  'DESCRIPTOR' : _STUDYSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.StudySpec)
  })
_sym_db.RegisterMessage(StudySpec)

StudyStatus = _reflection.GeneratedProtocolMessageType('StudyStatus', (_message.Message,), {
  'DESCRIPTOR' : _STUDYSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.StudyStatus)
  })
_sym_db.RegisterMessage(StudyStatus)

SuccessiveHalvingOptions = _reflection.GeneratedProtocolMessageType('SuccessiveHalvingOptions', (_message.Message,), {
  'DESCRIPTOR' : _SUCCESSIVEHALVINGOPTIONS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.SuccessiveHalvingOptions)
  })
_sym_db.RegisterMessage(SuccessiveHalvingOptions)

SuccessiveHalvingSpec = _reflection.GeneratedProtocolMessageType('SuccessiveHalvingSpec', (_message.Message,), {
  'DESCRIPTOR' : _SUCCESSIVEHALVINGSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.SuccessiveHalvingSpec)
  })
_sym_db.RegisterMessage(SuccessiveHalvingSpec)

TextPipelineSpec = _reflection.GeneratedProtocolMessageType('TextPipelineSpec', (_message.Message,), {
  'DESCRIPTOR' : _TEXTPIPELINESPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.TextPipelineSpec)
  })
_sym_db.RegisterMessage(TextPipelineSpec)

ThresholdPrunerOptions = _reflection.GeneratedProtocolMessageType('ThresholdPrunerOptions', (_message.Message,), {
  'DESCRIPTOR' : _THRESHOLDPRUNEROPTIONS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ThresholdPrunerOptions)
  })
_sym_db.RegisterMessage(ThresholdPrunerOptions)

TimeSeriesDataSpec = _reflection.GeneratedProtocolMessageType('TimeSeriesDataSpec', (_message.Message,), {
  'DESCRIPTOR' : _TIMESERIESDATASPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.TimeSeriesDataSpec)
  })
_sym_db.RegisterMessage(TimeSeriesDataSpec)

TrainingSpec = _reflection.GeneratedProtocolMessageType('TrainingSpec', (_message.Message,), {
  'DESCRIPTOR' : _TRAININGSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.TrainingSpec)
  })
_sym_db.RegisterMessage(TrainingSpec)

TrainingStageSpec = _reflection.GeneratedProtocolMessageType('TrainingStageSpec', (_message.Message,), {
  'DESCRIPTOR' : _TRAININGSTAGESPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.TrainingStageSpec)
  })
_sym_db.RegisterMessage(TrainingStageSpec)

UATStageSpec = _reflection.GeneratedProtocolMessageType('UATStageSpec', (_message.Message,), {
  'DESCRIPTOR' : _UATSTAGESPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.UATStageSpec)
  })
_sym_db.RegisterMessage(UATStageSpec)

VideoPipelineSpec = _reflection.GeneratedProtocolMessageType('VideoPipelineSpec', (_message.Message,), {
  'DESCRIPTOR' : _VIDEOPIPELINESPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.VideoPipelineSpec)
  })
_sym_db.RegisterMessage(VideoPipelineSpec)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z8github.com/metaprov/modelaapi/pkg/apis/training/v1alpha1'
  _MODELPIPELINESPEC_DATASETSELECTORENTRY._options = None
  _MODELPIPELINESPEC_DATASETSELECTORENTRY._serialized_options = b'8\001'
  _RUNTIMESTATUS_PYTHONPACKAGESENTRY._options = None
  _RUNTIMESTATUS_PYTHONPACKAGESENTRY._serialized_options = b'8\001'
  _ALGORITHMSEARCHSPACESPEC._serialized_start=472
  _ALGORITHMSEARCHSPACESPEC._serialized_end=517
  _AUDIOPIPELINESPEC._serialized_start=519
  _AUDIOPIPELINESPEC._serialized_end=558
  _BACKTESTSPEC._serialized_start=560
  _BACKTESTSPEC._serialized_end=659
  _BASELINESPEC._serialized_start=661
  _BASELINESPEC._serialized_end=724
  _CAPACITYSTAGESPEC._serialized_start=727
  _CAPACITYSTAGESPEC._serialized_end=962
  _CHANGEPOINTSPEC._serialized_start=964
  _CHANGEPOINTSPEC._serialized_end=1007
  _CHATBOTESTIMATORSPEC._serialized_start=1009
  _CHATBOTESTIMATORSPEC._serialized_end=1045
  _CHECKPOINTSPEC._serialized_start=1048
  _CHECKPOINTSPEC._serialized_end=1195
  _CLASSICALESTIMATORSPEC._serialized_start=1198
  _CLASSICALESTIMATORSPEC._serialized_end=1344
  _CRONREPORT._serialized_start=1347
  _CRONREPORT._serialized_end=1607
  _CRONREPORTCONDITION._serialized_start=1610
  _CRONREPORTCONDITION._serialized_end=1766
  _CRONREPORTLIST._serialized_start=1769
  _CRONREPORTLIST._serialized_end=1936
  _CRONREPORTSPEC._serialized_start=1939
  _CRONREPORTSPEC._serialized_end=2299
  _CRONREPORTSTATUS._serialized_start=2302
  _CRONREPORTSTATUS._serialized_end=2709
  _CUSTOMREPORTSPEC._serialized_start=2711
  _CUSTOMREPORTSPEC._serialized_end=2808
  _CUSTOMSEASONALITYSPEC._serialized_start=2810
  _CUSTOMSEASONALITYSPEC._serialized_end=2885
  _DATAHASHES._serialized_start=2887
  _DATAHASHES._serialized_end=2963
  _DATASPLITSPEC._serialized_start=2966
  _DATASPLITSPEC._serialized_end=3226
  _DATASTAGESPEC._serialized_start=3228
  _DATASTAGESPEC._serialized_end=3324
  _DEEPESTIMATORLAYER._serialized_start=3327
  _DEEPESTIMATORLAYER._serialized_end=3492
  _DEEPESTIMATORSPEC._serialized_start=3495
  _DEEPESTIMATORSPEC._serialized_end=3725
  _DEPLOYMENTSTAGESPEC._serialized_start=3728
  _DEPLOYMENTSTAGESPEC._serialized_end=3989
  _DRIFTDETECTIONSPEC._serialized_start=3991
  _DRIFTDETECTIONSPEC._serialized_end=4054
  _DRIFTDETECTORSTATUS._serialized_start=4056
  _DRIFTDETECTORSTATUS._serialized_end=4102
  _EARLYSTOPSPEC._serialized_start=4104
  _EARLYSTOPSPEC._serialized_end=4186
  _ENSEMBLERULES._serialized_start=4188
  _ENSEMBLERULES._serialized_end=4203
  _ENSEMBLESPEC._serialized_start=4206
  _ENSEMBLESPEC._serialized_end=4449
  _ENSEMBLESSPEC._serialized_start=4451
  _ENSEMBLESSPEC._serialized_end=4546
  _FEATUREENGINEERINGPIPELINE._serialized_start=4549
  _FEATUREENGINEERINGPIPELINE._serialized_end=5388
  _FEATUREENGINEERINGSEARCHSPEC._serialized_start=5391
  _FEATUREENGINEERINGSEARCHSPEC._serialized_end=5801
  _FEATUREENGINEERINGSEARCHSTATUS._serialized_start=5804
  _FEATUREENGINEERINGSEARCHSTATUS._serialized_end=5932
  _FEATUREENGINEERINGSPEC._serialized_start=5935
  _FEATUREENGINEERINGSPEC._serialized_end=6182
  _FEATUREIMPORTANCE._serialized_start=6184
  _FEATUREIMPORTANCE._serialized_end=6240
  _FEATUREINFO._serialized_start=6242
  _FEATUREINFO._serialized_end=6300
  _FEATUREPAIR._serialized_start=6302
  _FEATUREPAIR._serialized_end=6337
  _FEATURESELECTIONSPEC._serialized_start=6340
  _FEATURESELECTIONSPEC._serialized_end=6561
  _FORECASTOBJ._serialized_start=6563
  _FORECASTOBJ._serialized_end=6609
  _FORECASTPOSTPROCESSINGSPEC._serialized_start=6611
  _FORECASTPOSTPROCESSINGSPEC._serialized_end=6681
  _FORECASTSPEC._serialized_start=6684
  _FORECASTSPEC._serialized_end=7150
  _GARBAGECOLLECTIONSPEC._serialized_start=7152
  _GARBAGECOLLECTIONSPEC._serialized_end=7267
  _GARBAGECOLLECTIONSTATUS._serialized_start=7270
  _GARBAGECOLLECTIONSTATUS._serialized_end=7401
  _GENERATEDCOLUMNSPEC._serialized_start=7403
  _GENERATEDCOLUMNSPEC._serialized_end=7505
  _HIERARCHY._serialized_start=7508
  _HIERARCHY._serialized_end=7706
  _HIERARCHYSPEC._serialized_start=7708
  _HIERARCHYSPEC._serialized_end=7812
  _HOLIDAYSPEC._serialized_start=7814
  _HOLIDAYSPEC._serialized_end=7905
  _HYPERPARAMETERVALUE._serialized_start=7907
  _HYPERPARAMETERVALUE._serialized_end=7957
  _HYPERBANDOPTIONS._serialized_start=7959
  _HYPERBANDOPTIONS._serialized_end=8070
  _IMAGEPIPELINESPEC._serialized_start=8072
  _IMAGEPIPELINESPEC._serialized_end=8111
  _IMBALANCEHANDLINGSPEC._serialized_start=8113
  _IMBALANCEHANDLINGSPEC._serialized_end=8172
  _INTERPRETABILITYSPEC._serialized_start=8175
  _INTERPRETABILITYSPEC._serialized_end=8457
  _INTERPRETABILITYSTATUS._serialized_start=8460
  _INTERPRETABILITYSTATUS._serialized_end=8798
  _LEVEL._serialized_start=8800
  _LEVEL._serialized_end=8889
  _MEDIANPRUNEROPTIONS._serialized_start=8891
  _MEDIANPRUNEROPTIONS._serialized_end=8998
  _MODEL._serialized_start=9001
  _MODEL._serialized_end=9246
  _MODELAUTOBUILDER._serialized_start=9249
  _MODELAUTOBUILDER._serialized_end=9527
  _MODELAUTOBUILDERCONDITION._serialized_start=9530
  _MODELAUTOBUILDERCONDITION._serialized_end=9692
  _MODELAUTOBUILDERLIST._serialized_start=9695
  _MODELAUTOBUILDERLIST._serialized_end=9874
  _MODELAUTOBUILDERSPEC._serialized_start=9877
  _MODELAUTOBUILDERSPEC._serialized_end=10707
  _MODELAUTOBUILDERSTATUS._serialized_start=10710
  _MODELAUTOBUILDERSTATUS._serialized_end=11504
  _MODELCOMPILERRUN._serialized_start=11507
  _MODELCOMPILERRUN._serialized_end=11785
  _MODELCOMPILERRUNCONDITION._serialized_start=11788
  _MODELCOMPILERRUNCONDITION._serialized_end=11950
  _MODELCOMPILERRUNLIST._serialized_start=11953
  _MODELCOMPILERRUNLIST._serialized_end=12132
  _MODELCOMPILERRUNSPEC._serialized_start=12135
  _MODELCOMPILERRUNSPEC._serialized_end=12285
  _MODELCOMPILERRUNSTATUS._serialized_start=12288
  _MODELCOMPILERRUNSTATUS._serialized_end=12742
  _MODELCONDITION._serialized_start=12745
  _MODELCONDITION._serialized_end=12896
  _MODELIMAGESPEC._serialized_start=12898
  _MODELIMAGESPEC._serialized_end=12980
  _MODELLIST._serialized_start=12983
  _MODELLIST._serialized_end=13140
  _MODELPIPELINE._serialized_start=13143
  _MODELPIPELINE._serialized_end=13412
  _MODELPIPELINECONDITION._serialized_start=13415
  _MODELPIPELINECONDITION._serialized_end=13574
  _MODELPIPELINELIST._serialized_start=13577
  _MODELPIPELINELIST._serialized_end=13750
  _MODELPIPELINERUN._serialized_start=13753
  _MODELPIPELINERUN._serialized_end=14031
  _MODELPIPELINERUNCONDITION._serialized_start=14034
  _MODELPIPELINERUNCONDITION._serialized_end=14196
  _MODELPIPELINERUNLIST._serialized_start=14199
  _MODELPIPELINERUNLIST._serialized_end=14378
  _MODELPIPELINERUNSPEC._serialized_start=14381
  _MODELPIPELINERUNSPEC._serialized_end=14567
  _MODELPIPELINERUNSTAGESTATUS._serialized_start=14570
  _MODELPIPELINERUNSTAGESTATUS._serialized_end=14947
  _MODELPIPELINERUNSTATUS._serialized_start=14950
  _MODELPIPELINERUNSTATUS._serialized_end=16374
  _MODELPIPELINESPEC._serialized_start=16377
  _MODELPIPELINESPEC._serialized_end=17461
  _MODELPIPELINESPEC_DATASETSELECTORENTRY._serialized_start=17407
  _MODELPIPELINESPEC_DATASETSELECTORENTRY._serialized_end=17461
  _MODELPIPELINESTATUS._serialized_start=17464
  _MODELPIPELINESTATUS._serialized_end=17877
  _MODELRESULT._serialized_start=17879
  _MODELRESULT._serialized_end=17966
  _MODELSPEC._serialized_start=17969
  _MODELSPEC._serialized_end=19771
  _MODELSTATUS._serialized_start=19774
  _MODELSTATUS._serialized_end=23143
  _MODELTEST._serialized_start=23146
  _MODELTEST._serialized_end=23282
  _MODELTESTRESULT._serialized_start=23285
  _MODELTESTRESULT._serialized_end=23519
  _NLPESTIMATORSPEC._serialized_start=23521
  _NLPESTIMATORSPEC._serialized_end=23553
  _NNLAYERPARAMETER._serialized_start=23555
  _NNLAYERPARAMETER._serialized_end=23602
  _NOTEBOOK._serialized_start=23605
  _NOTEBOOK._serialized_end=23859
  _NOTEBOOKCONDITION._serialized_start=23862
  _NOTEBOOKCONDITION._serialized_end=24016
  _NOTEBOOKLIST._serialized_start=24019
  _NOTEBOOKLIST._serialized_end=24182
  _NOTEBOOKRUN._serialized_start=24185
  _NOTEBOOKRUN._serialized_end=24448
  _NOTEBOOKRUNCONDITION._serialized_start=24451
  _NOTEBOOKRUNCONDITION._serialized_end=24608
  _NOTEBOOKRUNLIST._serialized_start=24611
  _NOTEBOOKRUNLIST._serialized_end=24780
  _NOTEBOOKRUNSPEC._serialized_start=24783
  _NOTEBOOKRUNSPEC._serialized_end=25106
  _NOTEBOOKRUNSTATUS._serialized_start=25109
  _NOTEBOOKRUNSTATUS._serialized_end=25605
  _NOTEBOOKSPEC._serialized_start=25608
  _NOTEBOOKSPEC._serialized_end=26140
  _NOTEBOOKSTATUS._serialized_start=26143
  _NOTEBOOKSTATUS._serialized_end=26574
  _NOTEBOOKVARVALUE._serialized_start=26576
  _NOTEBOOKVARVALUE._serialized_end=26623
  _PERCENTILEPRUNEROPTIONS._serialized_start=26626
  _PERCENTILEPRUNEROPTIONS._serialized_end=26758
  _PERIODSEASONALITYSPEC._serialized_start=26760
  _PERIODSEASONALITYSPEC._serialized_end=26831
  _PERIODSPEC._serialized_start=26833
  _PERIODSPEC._serialized_end=26894
  _PRUNERSPEC._serialized_start=26897
  _PRUNERSPEC._serialized_end=27428
  _REGRESSORSPEC._serialized_start=27430
  _REGRESSORSPEC._serialized_end=27500
  _RELEASESTAGESPEC._serialized_start=27503
  _RELEASESTAGESPEC._serialized_end=27796
  _REPORT._serialized_start=27799
  _REPORT._serialized_end=28047
  _REPORTCONDITION._serialized_start=28050
  _REPORTCONDITION._serialized_end=28202
  _REPORTLIST._serialized_start=28205
  _REPORTLIST._serialized_end=28364
  _REPORTSPEC._serialized_start=28367
  _REPORTSPEC._serialized_end=28905
  _REPORTSTATUS._serialized_start=28908
  _REPORTSTATUS._serialized_end=29386
  _REPORTTEMPLATE._serialized_start=29388
  _REPORTTEMPLATE._serialized_end=29488
  _RESOURCECONSUMPTION._serialized_start=29490
  _RESOURCECONSUMPTION._serialized_end=29550
  _RUNTIMESTATUS._serialized_start=29553
  _RUNTIMESTATUS._serialized_end=29794
  _RUNTIMESTATUS_PYTHONPACKAGESENTRY._serialized_start=29741
  _RUNTIMESTATUS_PYTHONPACKAGESENTRY._serialized_end=29794
  _SEARCHSPEC._serialized_start=29797
  _SEARCHSPEC._serialized_end=30295
  _SEGMENTSPEC._serialized_start=30297
  _SEGMENTSPEC._serialized_end=30357
  _SERVINGSPEC._serialized_start=30359
  _SERVINGSPEC._serialized_end=30478
  _STUDY._serialized_start=30481
  _STUDY._serialized_end=30726
  _STUDYCONDITION._serialized_start=30729
  _STUDYCONDITION._serialized_end=30880
  _STUDYFORECASTSPEC._serialized_start=30883
  _STUDYFORECASTSPEC._serialized_end=31080
  _STUDYLIST._serialized_start=31083
  _STUDYLIST._serialized_end=31240
  _STUDYPHASESTATUS._serialized_start=31243
  _STUDYPHASESTATUS._serialized_end=31503
  _STUDYSCHEDULESPEC._serialized_start=31505
  _STUDYSCHEDULESPEC._serialized_end=31602
  _STUDYSPEC._serialized_start=31605
  _STUDYSPEC._serialized_end=33586
  _STUDYSTATUS._serialized_start=33589
  _STUDYSTATUS._serialized_end=35530
  _SUCCESSIVEHALVINGOPTIONS._serialized_start=35532
  _SUCCESSIVEHALVINGOPTIONS._serialized_end=35659
  _SUCCESSIVEHALVINGSPEC._serialized_start=35661
  _SUCCESSIVEHALVINGSPEC._serialized_end=35765
  _TEXTPIPELINESPEC._serialized_start=35768
  _TEXTPIPELINESPEC._serialized_end=35941
  _THRESHOLDPRUNEROPTIONS._serialized_start=35943
  _THRESHOLDPRUNEROPTIONS._serialized_end=36041
  _TIMESERIESDATASPEC._serialized_start=36044
  _TIMESERIESDATASPEC._serialized_end=37195
  _TRAININGSPEC._serialized_start=37198
  _TRAININGSPEC._serialized_end=37866
  _TRAININGSTAGESPEC._serialized_start=37868
  _TRAININGSTAGESPEC._serialized_end=37970
  _UATSTAGESPEC._serialized_start=37973
  _UATSTAGESPEC._serialized_end=38203
  _VIDEOPIPELINESPEC._serialized_start=38205
  _VIDEOPIPELINESPEC._serialized_end=38244
# @@protoc_insertion_point(module_scope)
